@@ -45,7 +45,7 @@
 #include "brasero-disc-copy-dialog.h"
 #include "brasero-burn-dialog.h"
 #include "burn-debug.h"
-#include "burn-drive.h"
+#include "brasero-drive.h"
 #include "burn-caps.h"
 #include "burn.h"
 #include "burn-plugin-manager.h"
@@ -75,7 +75,9 @@ struct _BraseroAppPrivate
 	gint height;
 
 	gchar *saved_contents;
+
 	guint is_maximised:1;
+	guint mainwin_running:1;
 };
 
 #define BRASERO_APP_PRIVATE(o)  (G_TYPE_INSTANCE_GET_PRIVATE ((o), BRASERO_TYPE_APP, BraseroAppPrivate))
@@ -489,6 +491,7 @@ brasero_app_dialog (BraseroApp *app,
 					 GTK_DIALOG_MODAL,
 					 msg_type,
 					 button_type,
+					 "%s",
 					 primary_message);
 
 	if (!toplevel && priv->parent) {
@@ -908,7 +911,7 @@ brasero_app_current_toplevel_destroyed (GtkWidget *widget,
 	BraseroAppPrivate *priv;
 
 	priv = BRASERO_APP_PRIVATE (app);
-	if (priv->mainwin)
+	if (priv->mainwin_running)
 		gtk_widget_show (GTK_WIDGET (priv->mainwin));
 }
 
@@ -919,8 +922,10 @@ brasero_app_set_toplevel (BraseroApp *app, GtkWindow *window)
 
 	priv = BRASERO_APP_PRIVATE (app);
 
-	if (!priv->mainwin) {
+	if (!priv->mainwin_running) {
 		if (priv->parent) {
+			gtk_window_set_skip_taskbar_hint (GTK_WINDOW (window), TRUE);
+			gtk_window_set_skip_pager_hint (GTK_WINDOW (window), TRUE);
 			gtk_widget_realize (GTK_WIDGET (window));
 			gtk_window_set_modal (GTK_WINDOW (window), TRUE);
 			gdk_window_set_transient_for (GTK_WIDGET (window)->window, priv->parent);
@@ -984,8 +989,8 @@ on_about_cb (GtkAction *action, BraseroApp *app)
 	};
 
 	const gchar *documenters[] = {
-		"Phil Bull <philbull@gmail.com>"
-		"Milo Casagrande <milo_casagrande@yahoo.it>"
+		"Phil Bull <philbull@gmail.com>\n"
+		"Milo Casagrande <milo_casagrande@yahoo.it>\n"
 		"Andrew Stabeno <stabeno@gmail.com>",
 		NULL
 	};
@@ -1209,7 +1214,7 @@ brasero_menu_item_selected_cb (GtkMenuItem *proxy,
 
 	priv = BRASERO_APP_PRIVATE (app);
 
-	action = g_object_get_data (G_OBJECT (proxy),  "gtk-action");
+	action = gtk_widget_get_action (GTK_WIDGET (proxy));
 	g_return_if_fail (action != NULL);
 
 	g_object_get (G_OBJECT (action), "tooltip", &message, NULL);
@@ -1429,6 +1434,7 @@ brasero_app_run_mainwin (BraseroApp *app)
 
 	priv = BRASERO_APP_PRIVATE (app);
 
+	priv->mainwin_running = 1;
 	gtk_widget_show (GTK_WIDGET (priv->mainwin));
 	gtk_main ();
 }
