@@ -57,7 +57,7 @@
 #include "burn-basics.h"
 #include "burn-track.h"
 #include "burn-session.h"
-#include "burn-volume-obj.h"
+#include "brasero-volume.h"
 
 
 typedef struct _BraseroDataDiscPrivate BraseroDataDiscPrivate;
@@ -203,7 +203,7 @@ static void
 brasero_data_disc_import_failure_dialog (BraseroDataDisc *disc,
 					 GError *error)
 {
-	brasero_app_alert (BRASERO_APP (gtk_widget_get_toplevel (GTK_WIDGET (disc))),
+	brasero_app_alert (brasero_app_get_default (),
 			   _("The session could not be imported."),
 			   error?error->message:_("An unknown error occured"),
 			   GTK_MESSAGE_WARNING);
@@ -624,7 +624,7 @@ brasero_data_disc_project_oversized_cb (BraseroDataProject *project,
 	}
 	else if (oversized) {
 		message = brasero_notify_message_add (BRASERO_NOTIFY (priv->message),
-						      _("Please, delete some files from the project."),
+						      _("Please delete some files from the project."),
 						      _("The size of the project is too large for the disc even with the overburn option."),
 						      -1,
 						      BRASERO_NOTIFY_CONTEXT_SIZE);
@@ -665,19 +665,19 @@ brasero_data_disc_project_loaded_cb (BraseroDataProject *project,
 		brasero_disc_message_set_primary (BRASERO_DISC_MESSAGE (message),
 						  _("The contents of the project changed since it was saved."));
 		brasero_disc_message_set_secondary (BRASERO_DISC_MESSAGE (message),
-						    _("Do you want to continue or discard the old project layout?"));
+						    _("Discard the current modified project"));
 
 		brasero_disc_message_set_image (BRASERO_DISC_MESSAGE (message),GTK_STOCK_DIALOG_WARNING);
 		brasero_disc_message_set_progress_active (BRASERO_DISC_MESSAGE (message), FALSE);
 		brasero_notify_button_add (BRASERO_NOTIFY (priv->message),
 					   BRASERO_DISC_MESSAGE (message),
 					   _("_Discard"),
-					   _("Press if you want to discard the current modified project"),
+					   _("Discard the current modified project"),
 					   GTK_RESPONSE_CANCEL);
 		brasero_notify_button_add (BRASERO_NOTIFY (priv->message),
 					   BRASERO_DISC_MESSAGE (message),
 					   _("_Continue"),
-					   _("Press if you want to continue with the current modified project"),
+					   _("Continue with the current modified project"),
 					   GTK_RESPONSE_OK);
 
 		brasero_disc_message_add_errors (BRASERO_DISC_MESSAGE (message),
@@ -742,21 +742,16 @@ static gboolean
 brasero_data_disc_switch_to_image (gpointer data)
 {
 	GtkWidget *manager;
-	GtkWidget *toplevel;
 	BraseroDataDiscPrivate *priv;
 	BraseroDataDiscProjectSwitch *callback_data = data;
 
 	priv = BRASERO_DATA_DISC_PRIVATE (callback_data->disc);
 
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (callback_data->disc));
-	if (!BRASERO_IS_APP (toplevel))
-		return BRASERO_BURN_OK;
-
 	/* Clean up everything to avoid warning dialog */
 	brasero_data_project_reset (priv->project);
 
 	/* Tell project manager to switch */
-	manager = brasero_app_get_project_manager (BRASERO_APP (toplevel));
+	manager = brasero_app_get_project_manager (brasero_app_get_default ());
 	brasero_project_manager_iso (BRASERO_PROJECT_MANAGER (manager),
 				     callback_data->uri);
 
@@ -773,7 +768,6 @@ brasero_data_disc_image_uri_cb (BraseroDataVFS *vfs,
 	gchar *string;
 	GtkWidget *button;
 	GtkWidget *dialog;
-	GtkWidget *toplevel;
 	BraseroDataDiscPrivate *priv;
 	BraseroDataDiscProjectSwitch *callback_data;
 
@@ -782,13 +776,9 @@ brasero_data_disc_image_uri_cb (BraseroDataVFS *vfs,
 	if (priv->loading)
 		return BRASERO_BURN_OK;
 
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (self));
-	if (!BRASERO_IS_APP (toplevel))
-		return BRASERO_BURN_OK;
-
 	name = brasero_file_node_get_uri_name (uri);
 	string = g_strdup_printf (_("Do you want to burn \"%s\" to a disc or add it in to the data project?"), name);
-	dialog = brasero_app_dialog (BRASERO_APP (toplevel),
+	dialog = brasero_app_dialog (brasero_app_get_default (),
 				     string,
 				     GTK_BUTTONS_NONE,
 				     GTK_MESSAGE_QUESTION);
@@ -884,7 +874,7 @@ brasero_data_disc_unreadable_uri_cb (BraseroDataVFS *vfs,
 	}
 
 	primary = g_strdup_printf (_("\"%s\" cannot be added to the selection."), name);
-	brasero_app_alert (BRASERO_APP (gtk_widget_get_toplevel (GTK_WIDGET (self))),
+	brasero_app_alert (brasero_app_get_default (),
 			   primary,
 			   error->message,
 			   GTK_MESSAGE_ERROR);
@@ -915,7 +905,7 @@ brasero_data_disc_recursive_uri_cb (BraseroDataVFS *vfs,
 	}
 
 	primary = g_strdup_printf (_("\"%s\" cannot be added to the selection."), name);
-	brasero_app_alert (BRASERO_APP (gtk_widget_get_toplevel (GTK_WIDGET (self))),
+	brasero_app_alert (brasero_app_get_default (),
 			   primary,
 			   _("It is a recursive symlink"),
 			   GTK_MESSAGE_ERROR);
@@ -946,7 +936,7 @@ brasero_data_disc_unknown_uri_cb (BraseroDataVFS *vfs,
 	}
 
 	primary = g_strdup_printf (_("\"%s\" cannot be added to the selection."), name);
-	brasero_app_alert (BRASERO_APP (gtk_widget_get_toplevel (GTK_WIDGET (self))),
+	brasero_app_alert (brasero_app_get_default (),
 			   primary,
 			   _("It does not exist at the specified location"),
 			   GTK_MESSAGE_ERROR);
@@ -962,7 +952,6 @@ brasero_data_disc_name_collision_cb (BraseroDataProject *project,
 	gint answer;
 	gchar *string;
 	GtkWidget *dialog;
-	GtkWidget *toplevel;
 	BraseroDataDiscPrivate *priv;
 
 	priv = BRASERO_DATA_DISC_PRIVATE (self);
@@ -972,9 +961,8 @@ brasero_data_disc_name_collision_cb (BraseroDataProject *project,
 		return FALSE;
 	}
 
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (self));
 	string = g_strdup_printf (_("Do you really want to replace \"%s\"?"), name);
-	dialog = brasero_app_dialog (BRASERO_APP (toplevel),
+	dialog = brasero_app_dialog (brasero_app_get_default (),
 				     string,
 				     GTK_BUTTONS_NONE,
 				     GTK_MESSAGE_WARNING);
@@ -1003,7 +991,6 @@ brasero_data_disc_2G_file_cb (BraseroDataProject *project,
 	gint answer;
 	gchar *string;
 	GtkWidget *dialog;
-	GtkWidget *toplevel;
 	BraseroDataDiscPrivate *priv;
 
 	priv = BRASERO_DATA_DISC_PRIVATE (self);
@@ -1017,18 +1004,17 @@ brasero_data_disc_2G_file_cb (BraseroDataProject *project,
 		return FALSE;
 	}
 
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (self));
 	string = g_strdup_printf (_("Do you really want to add \"%s\" to the selection and use the third version of ISO9660 standard to support it?"), name);
-	dialog = brasero_app_dialog (BRASERO_APP (toplevel),
+	dialog = brasero_app_dialog (brasero_app_get_default (),
 				     string,
 				     GTK_BUTTONS_NONE,
 				     GTK_MESSAGE_WARNING);
 	g_free (string);
 
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						  _("The size of the file is over 2 GiB. This isn't supported by ISO9660 standard in his first and second versions (the most widespread ones)."
+						  _("The size of the file is over 2 GiB. Files larger than 2 GiB are not supported by ISO9660 standard in its first and second versions (the most widespread ones)."
 						    "\nIt is recommended to use the third version of ISO9660 standard which is supported by most of the operating systems including Linux and all versions of Windows ©."
-						    "\nA known exception is MacOS X that cannot read images created with version 3 of ISO9660 standard."));
+						    "\nHowever MacOS X cannot read images created with version 3 of ISO9660 standard."));
 
 	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CANCEL, GTK_RESPONSE_NO);
 	gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Add File"), GTK_RESPONSE_YES);
@@ -1049,7 +1035,6 @@ brasero_data_disc_deep_directory_cb (BraseroDataProject *project,
 	gint answer;
 	gchar *string;
 	GtkWidget *dialog;
-	GtkWidget *toplevel;
 	BraseroDataDiscPrivate *priv;
 
 	priv = BRASERO_DATA_DISC_PRIVATE (self);
@@ -1063,17 +1048,15 @@ brasero_data_disc_deep_directory_cb (BraseroDataProject *project,
 		return FALSE;
 	}
 
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (self));
-
 	string = g_strdup_printf (_("Do you really want to add \"%s\" to the selection?"), name);
-	dialog = brasero_app_dialog (BRASERO_APP (toplevel),
+	dialog = brasero_app_dialog (brasero_app_get_default (),
 				     string,
 				     GTK_BUTTONS_NONE,
 				     GTK_MESSAGE_WARNING);
 	g_free (string);
 
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						  _("The children of this directory will have 6 parent directories. This is a violation of the ISO9660 standard which only allows 6."
+						  _("The children of this directory will have 7 parent directories."
 						    "\nBrasero can create an image of such a file hierarchy and burn it; but the disc may not be readable on all operating systems."
 						    "\nNOTE: Such a file hierarchy is known to work on linux."));
 
@@ -1699,7 +1682,7 @@ brasero_data_disc_load_track (BraseroDisc *disc,
 	}
 
 	message = brasero_notify_message_add (BRASERO_NOTIFY (priv->message),
-					      _("Please, wait while the project is loading."),
+					      _("Please wait while the project is loading."),
 					      NULL,
 					      -1,
 					      BRASERO_NOTIFY_CONTEXT_LOADING);
@@ -1710,7 +1693,7 @@ brasero_data_disc_load_track (BraseroDisc *disc,
 	brasero_notify_button_add (BRASERO_NOTIFY (priv->message),
 				   BRASERO_DISC_MESSAGE (message),
 				   _("_Cancel Loading"),
-				   _("Press if you want to cancel current project loading"),
+				   _("Cancel loading current project"),
 				   GTK_RESPONSE_CANCEL);
 	g_signal_connect (message,
 			  "response",
