@@ -34,15 +34,12 @@
 #include <glib/gi18n-lib.h>
 #include <glib-object.h>
 
-#include <gtk/gtkdialog.h>
-#include <gtk/gtkwindow.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtkbutton.h>
+#include <gtk/gtk.h>
 
 #include "burn-basics.h"
-#include "burn-drive.h"
-#include "burn-medium.h"
-#include "burn-volume-obj.h"
+#include "brasero-drive.h"
+#include "brasero-medium.h"
+#include "brasero-volume.h"
 #include "burn-session.h"
 #include "burn-caps.h"
 #include "burn-plugin-manager.h"
@@ -61,22 +58,19 @@ struct _BraseroDiscOptionDialogPrivate {
 	BraseroDisc *disc;
 
 	GtkWidget *joliet_toggle;
-	GtkWidget *multi_toggle;
 
 	GtkWidget *video_options;
-	GtkWidget *dvd_audio;
 	GtkWidget *vcd_label;
 	GtkWidget *vcd_button;
 	GtkWidget *svcd_button;
 
-	guint label_modified:1;
-	guint joliet_warning:1;
+	GtkWidget *button_4_3;
+	GtkWidget *button_16_9;
 
 	gulong valid_sig;
 
-	guint checksum_saved:1;
+	guint joliet_warning:1;
 	guint joliet_saved:1;
-	guint multi_saved:1;
 };
 typedef struct _BraseroDiscOptionDialogPrivate BraseroDiscOptionDialogPrivate;
 
@@ -84,35 +78,40 @@ typedef struct _BraseroDiscOptionDialogPrivate BraseroDiscOptionDialogPrivate;
 
 static GtkDialogClass *parent_class = NULL;
 
-static void
-brasero_disc_option_dialog_load_multi_state (BraseroDiscOptionDialog *dialog)
-{
-	BraseroDiscOptionDialogPrivate *priv;
-	BraseroBurnSession *session;
-	gboolean value;
 
-	priv = BRASERO_DISC_OPTION_DIALOG_PRIVATE (dialog);
+static void
+brasero_disc_option_audio_AC3 (BraseroDiscOptionDialog *dialog)
+{
+	BraseroBurnSession *session;
+	GValue *value = NULL;
 
 	session = brasero_burn_options_get_session (BRASERO_BURN_OPTIONS (dialog));
-	if (!brasero_session_cfg_is_supported (BRASERO_SESSION_CFG (session), BRASERO_BURN_FLAG_MULTI)) {
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->multi_toggle), FALSE);
-		gtk_widget_set_sensitive (priv->multi_toggle, FALSE);
-		g_object_unref (session);
-		return;
-	}
 
-	value = (brasero_burn_session_get_flags (session) & BRASERO_BURN_FLAG_MULTI) != 0;
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->multi_toggle), value);
+	value = g_new0 (GValue, 1);
+	g_value_init (value, G_TYPE_INT);
+	g_value_set_int (value, BRASERO_AUDIO_FORMAT_AC3);
+	brasero_burn_session_tag_add (session,
+				      BRASERO_DVD_AUDIO_STREAMS,
+				      value);
 
-	if (!value) {
-		g_object_unref (session);
-		return;
-	}
+	g_object_unref (session);
+}
+
+static void
+brasero_disc_option_audio_MP2 (BraseroDiscOptionDialog *dialog)
+{
+	BraseroBurnSession *session;
+	GValue *value = NULL;
+
+	session = brasero_burn_options_get_session (BRASERO_BURN_OPTIONS (dialog));
+
+	value = g_new0 (GValue, 1);
+	g_value_init (value, G_TYPE_INT);
+	g_value_set_int (value, BRASERO_AUDIO_FORMAT_MP2);
+	brasero_burn_session_tag_add (session,
+				      BRASERO_DVD_AUDIO_STREAMS,
+				      value);
 
-	/* set sensitivity */
-	value = brasero_session_cfg_is_compulsory (BRASERO_SESSION_CFG (session),
-						   BRASERO_BURN_FLAG_MULTI);
-	gtk_widget_set_sensitive (priv->multi_toggle, value != TRUE);
 	g_object_unref (session);
 }
 
@@ -182,36 +181,6 @@ brasero_disc_option_dialog_update_joliet (BraseroDiscOptionDialog *dialog)
 	return TRUE;
 }
 
-static void
-brasero_disc_option_dialog_update_multi (BraseroDiscOptionDialog *dialog)
-{
-	BraseroTrackType input;
-	BraseroBurnSession *session;
-	BraseroDiscOptionDialogPrivate *priv;
-
-	priv = BRASERO_DISC_OPTION_DIALOG_PRIVATE (dialog);
-
-	if (!priv->multi_toggle)
-		return;
-
-	session = brasero_burn_options_get_session (BRASERO_BURN_OPTIONS (dialog));
-	brasero_burn_session_get_input_type (session, &input);
-
-	/* MULTI and Video projects don't get along */
-	if (input.type == BRASERO_TRACK_TYPE_DATA
-	&& (input.subtype.fs_type & BRASERO_IMAGE_FS_VIDEO)
-	&& (brasero_burn_session_get_dest_media (session) & BRASERO_MEDIUM_DVD)) {
-		brasero_session_cfg_remove_flags (BRASERO_SESSION_CFG (session), BRASERO_BURN_FLAG_MULTI);
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->multi_toggle), FALSE);
-		gtk_widget_set_sensitive (priv->multi_toggle, FALSE);
-		g_object_unref (session);
-		return;
-	}
-
-	brasero_disc_option_dialog_load_multi_state (dialog);
-	g_object_unref (session);
-}
-
 static void
 brasero_disc_option_dialog_update_video (BraseroDiscOptionDialog *dialog)
 {
@@ -221,25 +190,41 @@ brasero_disc_option_dialog_update_video (BraseroDiscOptionDialog *dialog)
 
 	priv = BRASERO_DISC_OPTION_DIALOG_PRIVATE (dialog);
 
+	/* means we haven't initialized yet */
+	if (!priv->vcd_label)
+		return;
+
 	session = brasero_burn_options_get_session (BRASERO_BURN_OPTIONS (dialog));
 	media = brasero_burn_session_get_dest_media (session);
 
 	if (media & BRASERO_MEDIUM_DVD) {
-		gtk_widget_show (priv->dvd_audio);
+		brasero_disc_option_audio_AC3 (dialog);
 		gtk_widget_hide (priv->vcd_label);
 		gtk_widget_hide (priv->vcd_button);
 		gtk_widget_hide (priv->svcd_button);
+
+		gtk_widget_set_sensitive (priv->button_4_3, TRUE);
+		gtk_widget_set_sensitive (priv->button_16_9, TRUE);
 	}
 	else if (media & BRASERO_MEDIUM_CD) {
-		gtk_widget_hide (priv->dvd_audio);
+		brasero_disc_option_audio_MP2 (dialog);
 		gtk_widget_show (priv->vcd_label);
 		gtk_widget_show (priv->vcd_button);
 		gtk_widget_show (priv->svcd_button);
+
+		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->vcd_button))) {
+			gtk_widget_set_sensitive (priv->button_4_3, FALSE);
+			gtk_widget_set_sensitive (priv->button_16_9, FALSE);
+		}
+		else {
+			gtk_widget_set_sensitive (priv->button_4_3, TRUE);
+			gtk_widget_set_sensitive (priv->button_16_9, TRUE);
+		}
 	}
 	else if (media & BRASERO_MEDIUM_FILE) {
 		BraseroImageFormat format;
 
-		/* if we create a CUE file then that's a SVCD */
+		/* if we create a CUE file then that's a (S)VCD */
 		format = brasero_burn_session_get_output_format (session);
 		if (format == BRASERO_IMAGE_FORMAT_NONE) {
 			g_object_unref (session);
@@ -247,16 +232,28 @@ brasero_disc_option_dialog_update_video (BraseroDiscOptionDialog *dialog)
 		}
 
 		if (format == BRASERO_IMAGE_FORMAT_CUE) {
-			gtk_widget_hide (priv->dvd_audio);
+			brasero_disc_option_audio_MP2 (dialog);
 			gtk_widget_show (priv->vcd_label);
 			gtk_widget_show (priv->vcd_button);
 			gtk_widget_show (priv->svcd_button);
+
+			if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->vcd_button))) {
+				gtk_widget_set_sensitive (priv->button_4_3, FALSE);
+				gtk_widget_set_sensitive (priv->button_16_9, FALSE);
+			}
+			else {
+				gtk_widget_set_sensitive (priv->button_4_3, TRUE);
+				gtk_widget_set_sensitive (priv->button_16_9, TRUE);
+			}
 		}
 		else if (format == BRASERO_IMAGE_FORMAT_BIN) {
-			gtk_widget_show (priv->dvd_audio);
+			brasero_disc_option_audio_AC3 (dialog);
 			gtk_widget_hide (priv->vcd_label);
 			gtk_widget_hide (priv->vcd_button);
 			gtk_widget_hide (priv->svcd_button);
+
+			gtk_widget_set_sensitive (priv->button_4_3, TRUE);
+			gtk_widget_set_sensitive (priv->button_16_9, TRUE);
 		}
 	}
 
@@ -294,36 +291,6 @@ brasero_disc_option_dialog_set_joliet (BraseroDiscOptionDialog *dialog)
 	g_object_unref (session);
 }
 
-static void
-brasero_disc_option_dialog_set_multi (BraseroDiscOptionDialog *dialog)
-{
-	BraseroDiscOptionDialogPrivate *priv;
-	BraseroBurnSession *session;
-
-	priv = BRASERO_DISC_OPTION_DIALOG_PRIVATE (dialog);
-
-	if (!priv->multi_toggle)
-		return;
-
-	session = brasero_burn_options_get_session (BRASERO_BURN_OPTIONS (dialog));
-
-	if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->multi_toggle)))
-		brasero_session_cfg_remove_flags (BRASERO_SESSION_CFG (session),
-						  BRASERO_BURN_FLAG_MULTI);
-	else
-		brasero_session_cfg_add_flags (BRASERO_SESSION_CFG (session),
-					       BRASERO_BURN_FLAG_MULTI);
-
-	g_object_unref (session);
-}
-
-static void
-brasero_disc_option_dialog_multi_toggled (GtkToggleButton *multi_toggle,
-					  BraseroDiscOptionDialog *dialog)
-{
-	brasero_disc_option_dialog_set_multi (dialog);
-}
-
 static void
 brasero_disc_option_dialog_joliet_toggled_cb (GtkToggleButton *toggle,
 					      BraseroDiscOptionDialog *dialog)
@@ -331,6 +298,7 @@ brasero_disc_option_dialog_joliet_toggled_cb (GtkToggleButton *toggle,
 	BraseroDiscOptionDialogPrivate *priv;
 	GtkResponseType answer;
 	GtkWidget *message;
+	gchar *secondary;
 	gboolean hide;
 
 	priv = BRASERO_DISC_OPTION_DIALOG_PRIVATE (dialog);
@@ -352,18 +320,19 @@ brasero_disc_option_dialog_joliet_toggled_cb (GtkToggleButton *toggle,
 					  GTK_DIALOG_MODAL,
 					  GTK_MESSAGE_INFO,
 					  GTK_BUTTONS_NONE,
-					  _("Should files be renamed to be windows-compatible?"));
+					  _("Should files be renamed to be fully Windows-compatible?"));
 
-	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (message),
-						  _("Some files don't have a suitable name for a Windows-compatible CD. Those names will be changed and truncated to 64 characters."));
-
-	gtk_window_set_title (GTK_WINDOW (message), _("Windows Compatibility"));
+	secondary = g_strdup_printf ("%s\n%s",
+				     _("Some files don't have a suitable name for a fully Windows-compatible CD."),
+				     _("Those names should be changed and truncated to 64 characters."));
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (message), "%s", secondary);
+	g_free (secondary);
 
 	gtk_dialog_add_button (GTK_DIALOG (message),
-			       _("_Don't rename"),
+			       _("_Disable Full Windows Compatibility"),
 			       GTK_RESPONSE_CANCEL);
 	gtk_dialog_add_button (GTK_DIALOG (message),
-			       _("_Rename"),
+			       _("_Rename for Full Windows Compatibility"),
 			       GTK_RESPONSE_YES);
 
 	answer = gtk_dialog_run (GTK_DIALOG (message));
@@ -411,25 +380,6 @@ brasero_disc_option_dialog_joliet_widget (BraseroDiscOptionDialog *dialog)
 	return TRUE;
 }
 
-static gboolean
-brasero_disc_option_dialog_multi_widget (BraseroDiscOptionDialog *dialog)
-{
-	BraseroDiscOptionDialogPrivate *priv;
-
-	priv = BRASERO_DISC_OPTION_DIALOG_PRIVATE (dialog);
-	priv->multi_toggle = gtk_check_button_new_with_mnemonic (_("Leave the disc _open to add other files later"));
-
-	g_signal_connect (priv->multi_toggle,
-			  "toggled",
-			  G_CALLBACK (brasero_disc_option_dialog_multi_toggled),
-			  dialog);
-	gtk_widget_set_tooltip_text (priv->multi_toggle,
-			      _("Allow to add more data to the disc later"));
-
-	brasero_disc_option_dialog_update_multi (dialog);
-	return TRUE;
-}
-
 static void
 brasero_disc_option_dialog_add_data_options (BraseroDiscOptionDialog *dialog)
 {
@@ -445,15 +395,11 @@ brasero_disc_option_dialog_add_data_options (BraseroDiscOptionDialog *dialog)
 	widget = gtk_vbox_new (FALSE, 0);
 	brasero_burn_options_add_options (BRASERO_BURN_OPTIONS (dialog), widget);
 
-	/* multisession options */
-	brasero_disc_option_dialog_multi_widget (dialog);
-
 	/* general options */
 	brasero_disc_option_dialog_joliet_widget (dialog);
 
 	string = g_strdup_printf ("<b>%s</b>", _("Disc options"));
 	options = brasero_utils_pack_properties (string,
-						 priv->multi_toggle,
 						 priv->joliet_toggle,
 						 NULL);
 	g_free (string);
@@ -463,108 +409,6 @@ brasero_disc_option_dialog_add_data_options (BraseroDiscOptionDialog *dialog)
 	gtk_widget_show_all (widget);
 }
 
-static void
-brasero_disc_option_dialog_add_audio_options (BraseroDiscOptionDialog *dialog)
-{
-	gchar *string;
-	GtkWidget *widget;
-	GtkWidget *options;
-	BraseroDiscOptionDialogPrivate *priv;
-
-	priv = BRASERO_DISC_OPTION_DIALOG_PRIVATE (dialog);
-
-	widget = gtk_vbox_new (FALSE, 0);
-	brasero_burn_options_add_options (BRASERO_BURN_OPTIONS (dialog), widget);
-
-	/* multisession options */
-	priv->multi_toggle = gtk_check_button_new_with_mnemonic (_("Leave the disc _open to add a data session later"));
-	g_signal_connect (priv->multi_toggle,
-			  "toggled",
-			  G_CALLBACK (brasero_disc_option_dialog_multi_toggled),
-			  dialog);
-	gtk_widget_set_tooltip_text (priv->multi_toggle,
-				     _("Allow create what is called an enhanced CD or CD+"));
-
-	string = g_strdup_printf ("<b>%s</b>", _("Disc options"));
-	options = brasero_utils_pack_properties (string,
-						 priv->multi_toggle,
-						 NULL);
-	g_free (string);
-
-	gtk_box_pack_start (GTK_BOX (widget), options, FALSE, FALSE, 0);
-
-	brasero_disc_option_dialog_update_multi (dialog);
-	gtk_widget_show_all (widget);
-}
-
-static void
-brasero_disc_option_dialog_AC3 (GtkToggleButton *button,
-				BraseroDiscOptionDialog *dialog)
-{
-	BraseroBurnSession *session;
-	BraseroAudioFormat format;
-	GValue *value = NULL;
-
-	session = brasero_burn_options_get_session (BRASERO_BURN_OPTIONS (dialog));
-
-	brasero_burn_session_tag_lookup (session,
-					 BRASERO_DVD_AUDIO_STREAMS,
-					 &value);
-
-	if (value)
-		format = g_value_get_int (value);
-	else
-		format = BRASERO_AUDIO_FORMAT_NONE;
-
-	if (gtk_toggle_button_get_active (button))
-		format |= BRASERO_AUDIO_FORMAT_AC3;
-	else
-		format &= ~BRASERO_AUDIO_FORMAT_AC3;
-
-	value = g_new0 (GValue, 1);
-	g_value_init (value, G_TYPE_INT);
-	g_value_set_int (value, format);
-	brasero_burn_session_tag_add (session,
-				      BRASERO_DVD_AUDIO_STREAMS,
-				      value);
-
-	g_object_unref (session);
-}
-
-static void
-brasero_disc_option_dialog_MP2 (GtkToggleButton *button,
-				BraseroDiscOptionDialog *dialog)
-{
-	BraseroBurnSession *session;
-	BraseroAudioFormat format;
-	GValue *value = NULL;
-
-	session = brasero_burn_options_get_session (BRASERO_BURN_OPTIONS (dialog));
-
-	brasero_burn_session_tag_lookup (session,
-					 BRASERO_DVD_AUDIO_STREAMS,
-					 &value);
-
-	if (value)
-		format = g_value_get_int (value);
-	else
-		format = BRASERO_AUDIO_FORMAT_NONE;
-
-	if (gtk_toggle_button_get_active (button))
-		format |= BRASERO_AUDIO_FORMAT_MP2;
-	else
-		format &= ~BRASERO_AUDIO_FORMAT_MP2;
-
-	value = g_new0 (GValue, 1);
-	g_value_init (value, G_TYPE_INT);
-	g_value_set_int (value, format);
-	brasero_burn_session_tag_add (session,
-				      BRASERO_DVD_AUDIO_STREAMS,
-				      value);
-
-	g_object_unref (session);
-}
-
 static void
 brasero_disc_option_dialog_set_tag (BraseroDiscOptionDialog *dialog,
 				    const gchar *tag,
@@ -589,24 +433,39 @@ static void
 brasero_disc_option_dialog_SVCD (GtkToggleButton *button,
 				 BraseroDiscOptionDialog *dialog)
 {
+	BraseroDiscOptionDialogPrivate *priv;
+
 	if (!gtk_toggle_button_get_active (button))
 		return;
 
 	brasero_disc_option_dialog_set_tag (dialog,
 					    BRASERO_VCD_TYPE,
 					    BRASERO_SVCD);
+
+	priv = BRASERO_DISC_OPTION_DIALOG_PRIVATE (dialog);
+
+	gtk_widget_set_sensitive (priv->button_4_3, TRUE);
+	gtk_widget_set_sensitive (priv->button_16_9, TRUE);
 }
 
 static void
 brasero_disc_option_dialog_VCD (GtkToggleButton *button,
 				BraseroDiscOptionDialog *dialog)
 {
+	BraseroDiscOptionDialogPrivate *priv;
+
 	if (!gtk_toggle_button_get_active (button))
 		return;
 
 	brasero_disc_option_dialog_set_tag (dialog,
 					    BRASERO_VCD_TYPE,
 					    BRASERO_VCD_V2);
+
+	priv = BRASERO_DISC_OPTION_DIALOG_PRIVATE (dialog);
+	gtk_widget_set_sensitive (priv->button_4_3, FALSE);
+	gtk_widget_set_sensitive (priv->button_16_9, FALSE);
+
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->button_4_3), TRUE);
 }
 
 static void
@@ -671,20 +530,6 @@ brasero_disc_option_dialog_4_3 (GtkToggleButton *button,
 					    BRASERO_VIDEO_ASPECT_4_3);
 }
 
-static void
-brasero_disc_option_dialog_native_aspect (GtkToggleButton *button,
-					  BraseroDiscOptionDialog *dialog)
-{
-	BraseroBurnSession *session;
-
-	if (!gtk_toggle_button_get_active (button))
-		return;
-
-	session = brasero_burn_options_get_session (BRASERO_BURN_OPTIONS (dialog));
-	brasero_burn_session_tag_remove (session, BRASERO_VIDEO_OUTPUT_ASPECT);
-	g_object_unref (session);
-}
-
 static void
 brasero_disc_option_dialog_add_video_options (BraseroDiscOptionDialog *dialog)
 {
@@ -783,11 +628,12 @@ brasero_disc_option_dialog_add_video_options (BraseroDiscOptionDialog *dialog)
 			  dialog);
 	gtk_table_attach (GTK_TABLE (table),
 			  button1,
-			  3, 4,
+			  1, 2,
 			  1, 2,
 			  GTK_FILL,
 			  GTK_FILL,
 			  0, 0);
+	priv->button_4_3 = button1;
 
 	button2 = gtk_radio_button_new_with_mnemonic_from_widget (GTK_RADIO_BUTTON (button1),
 								  _("_16:9"));
@@ -802,21 +648,7 @@ brasero_disc_option_dialog_add_video_options (BraseroDiscOptionDialog *dialog)
 			  GTK_FILL,
 			  GTK_FILL,
 			  0, 0);
-
-	button3 = gtk_radio_button_new_with_mnemonic_from_widget (GTK_RADIO_BUTTON (button1),
-								  _("Native aspect _ratio"));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button3), TRUE);
-	g_signal_connect (button3,
-			  "toggled",
-			  G_CALLBACK (brasero_disc_option_dialog_native_aspect),
-			  dialog);
-	gtk_table_attach (GTK_TABLE (table),
-			  button3,
-			  1, 2,
-			  1, 2,
-			  GTK_FILL,
-			  GTK_FILL,
-			  0, 0);
+	priv->button_16_9 = button2;
 
 	/* Video options for (S)VCD */
 	label = gtk_label_new (_("VCD type:"));
@@ -870,33 +702,22 @@ brasero_disc_option_dialog_add_video_options (BraseroDiscOptionDialog *dialog)
 
 	gtk_box_pack_start (GTK_BOX (widget), options, FALSE, FALSE, 0);
 
-	/* Audio options for DVDs */
-	button1 = gtk_check_button_new_with_mnemonic (_("Add _AC3 audio stream"));
-	button2 = gtk_check_button_new_with_mnemonic (_("Add _MP2 audio stream"));
-
-	string = g_strdup_printf ("<b>%s</b>", _("Audio Options"));
-	options = brasero_utils_pack_properties (string,
-						 button1,
-						 button2,
-						 NULL);
-	g_free (string);
-
-	g_signal_connect (button1,
-			  "clicked",
-			  G_CALLBACK (brasero_disc_option_dialog_AC3),
-			  dialog);
-	g_signal_connect (button2,
-			  "clicked",
-			  G_CALLBACK (brasero_disc_option_dialog_MP2),
-			  dialog);
-
-	gtk_box_pack_start (GTK_BOX (widget), options, FALSE, FALSE, 0);
-	priv->dvd_audio = options;
+	/* NOTE: audio options for DVDs were removed. For SVCD that is MP2 and
+	 * for Video DVD even if we have a choice AC3 is the most widespread
+	 * audio format. So use AC3 by default. */
 
 	gtk_widget_show_all (widget);
 	brasero_disc_option_dialog_update_video (dialog);
 
 	priv->video_options = widget;
+
+	/* Just to make sure our tags are correct in BraseroBurnSession */
+	brasero_disc_option_dialog_set_tag (dialog,
+					    BRASERO_VCD_TYPE,
+					    BRASERO_SVCD);
+	brasero_disc_option_dialog_set_tag (dialog,
+					    BRASERO_VIDEO_OUTPUT_ASPECT,
+					    BRASERO_VIDEO_ASPECT_4_3);
 }
 
 void
@@ -933,9 +754,9 @@ brasero_disc_option_dialog_set_disc (BraseroDiscOptionDialog *dialog,
 			brasero_disc_option_dialog_add_video_options (dialog);
 		}
 		else {
+			/* No other specific options for audio */
 			brasero_burn_options_set_type_shown (BRASERO_BURN_OPTIONS (dialog),
 							     BRASERO_MEDIA_TYPE_WRITABLE);
-			brasero_disc_option_dialog_add_audio_options (dialog);
 		}
 	}
 
@@ -968,17 +789,13 @@ brasero_disc_option_dialog_valid_media_cb (BraseroSessionCfg *session,
 	priv = BRASERO_DISC_OPTION_DIALOG_PRIVATE (self);
 
 	if (priv->video_options)
-		gtk_widget_set_sensitive (priv->video_options, brasero_session_cfg_get_error (session) == BRASERO_SESSION_VALID);
+		gtk_widget_set_sensitive (priv->video_options, BRASERO_SESSION_IS_VALID (brasero_session_cfg_get_error (session)));
 
 	/* update the joliet button */
 	brasero_disc_option_dialog_update_joliet (self);
 
-	/* for video disc see what's the output : CD or DVD */
-	if (priv->dvd_audio)
-		brasero_disc_option_dialog_update_video (self);
-
-	/* flags could have changed so make sure multi gets updated */
-	brasero_disc_option_dialog_update_multi (self);
+	/* for video disc see what's the output: CD or DVD */
+	brasero_disc_option_dialog_update_video (self);
 }
 
 static void
