@@ -42,9 +42,9 @@
 
 #include "brasero-sum-dialog.h"
 #include "brasero-tool-dialog.h"
-#include "burn-drive.h"
-#include "burn-medium.h"
-#include "burn-volume-obj.h"
+#include "brasero-drive.h"
+#include "brasero-medium.h"
+#include "brasero-volume.h"
 #include "brasero-xfer.h"
 #include "burn-basics.h"
 #include "burn-debug.h"
@@ -175,13 +175,15 @@ brasero_sum_dialog_corruption_warning (BraseroSumDialog *self,
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
 
-	string = g_strdup_printf ("<b><big>%s</big></b>", _("The following files appear to be corrupted:"));
+	string = g_strdup_printf ("<b><big>%s</big></b>",
+				  _("The following files appear to be corrupted:"));
+
 	message = gtk_message_dialog_new_with_markup (GTK_WINDOW (self),
 						      GTK_DIALOG_MODAL |
 						      GTK_DIALOG_DESTROY_WITH_PARENT,
 						      GTK_MESSAGE_ERROR,
 						      GTK_BUTTONS_NONE,
-						      "%s", string);
+						      string);
 	g_free (string);
 
 	gtk_window_set_resizable (GTK_WINDOW (message), TRUE);
@@ -512,81 +514,10 @@ brasero_sum_dialog_check_md5_file (BraseroSumDialog *self,
 	return brasero_sum_dialog_success (self);
 }
 
-static BraseroChecksumType
-brasero_sum_dialog_set_track_checksum_type (BraseroSumDialog *self,
-					    BraseroDrive *drive,
-					    BraseroTrack *track,
-					    GError **error)
-{
-	BraseroMedium *medium;
-	gboolean retval;
-	gchar *filename;
-	gchar *root;
-
-	medium = brasero_drive_get_medium (drive);
-
-	retval = brasero_volume_mount (BRASERO_VOLUME (medium), TRUE, error);
-	if (!retval)
-		return BRASERO_CHECKSUM_NONE;
-
-	root = brasero_volume_get_mount_point (BRASERO_VOLUME (medium), error);
-	if (!root)
-		return BRASERO_CHECKSUM_NONE;
-
-	filename = g_build_path (G_DIR_SEPARATOR_S, root, BRASERO_MD5_FILE, NULL);
-
-	if (g_file_test (filename, G_FILE_TEST_EXISTS)) {
-		g_free (filename);
-		g_free (root);
-
-		brasero_track_set_checksum (track,
-					    BRASERO_CHECKSUM_MD5_FILE,
-					    BRASERO_MD5_FILE);
-
-		return BRASERO_CHECKSUM_MD5_FILE;
-	}
-	g_free (filename);
-
-	filename = g_build_path (G_DIR_SEPARATOR_S, root, BRASERO_SHA1_FILE, NULL);
-	if (g_file_test (filename, G_FILE_TEST_EXISTS)) {
-		g_free (filename);
-		g_free (root);
-
-		brasero_track_set_checksum (track,
-					    BRASERO_CHECKSUM_SHA1_FILE,
-					    BRASERO_SHA1_FILE);
-
-		return BRASERO_CHECKSUM_SHA1_FILE;
-	}
-	g_free (filename);
-
-	filename = g_build_path (G_DIR_SEPARATOR_S, root, BRASERO_SHA256_FILE, NULL);
-	if (g_file_test (filename, G_FILE_TEST_EXISTS)) {
-		g_free (filename);
-		g_free (root);
-
-		brasero_track_set_checksum (track,
-					    BRASERO_CHECKSUM_SHA256_FILE,
-					    BRASERO_SHA256_FILE);
-
-		return BRASERO_CHECKSUM_SHA256_FILE;
-	}
-	g_free (filename);
-	g_free (root);
-
-	g_set_error (error,
-		     BRASERO_ERROR,
-		     BRASERO_ERROR_GENERAL,
-		     _("No checksum file could be found on the disc"));
-
-	return BRASERO_CHECKSUM_NONE;
-}
-
 static gboolean
 brasero_sum_dialog_check_disc_sum (BraseroSumDialog *self,
 				   BraseroDrive *drive)
 {
-	BraseroChecksumType checksum_type;
 	BraseroBurnResult result;
 	GError *error = NULL;
 	GValue *value = NULL;
@@ -594,29 +525,15 @@ brasero_sum_dialog_check_disc_sum (BraseroSumDialog *self,
 	BraseroBurn *burn;
 	gboolean retval;
 
-	/* get the checksum */
+	/* make track */
 	track = brasero_track_new (BRASERO_TRACK_TYPE_DISC);
 	brasero_track_set_drive_source (track, drive);
-
-	checksum_type = brasero_sum_dialog_set_track_checksum_type (self,
-								    drive,
-								    track,
-								    &error);
-
-	if (checksum_type == BRASERO_CHECKSUM_NONE) {
-		retval = brasero_sum_dialog_message_error (self, error);
-		brasero_track_unref (track);
-
-		if (error)
-			g_error_free (error);
-
-		return retval;
-	}
-
-	/* no eject at the end (it's default) */
-	brasero_burn_session_remove_flag (self->priv->session, BRASERO_BURN_FLAG_EJECT);
+	brasero_track_set_checksum (track, BRASERO_CHECKSUM_DETECT, NULL);
 	brasero_burn_session_add_track (self->priv->session, track);
 
+	/* no eject at the end (it should be default) */
+	brasero_burn_session_remove_flag (self->priv->session, BRASERO_BURN_FLAG_EJECT);
+
 	/* It's good practice to unref the track afterwards as we don't need it
 	 * anymore. BraseroBurnSession refs it. */
 	brasero_track_unref (track);
@@ -758,7 +675,8 @@ brasero_sum_dialog_init (BraseroSumDialog *obj)
 
 	/* only media with data, no blank medium */
 	brasero_tool_dialog_set_medium_type_shown (BRASERO_TOOL_DIALOG (obj),
-						   BRASERO_MEDIA_TYPE_READABLE);
+						   BRASERO_MEDIA_TYPE_AUDIO|
+						   BRASERO_MEDIA_TYPE_DATA);
 
 	medium = brasero_tool_dialog_get_medium (BRASERO_TOOL_DIALOG (obj));
 	if (medium) {
