@@ -7,12 +7,13 @@
  ****************************************************************************/
 
 /*
- * This program is free software; you can redistribute it and/or modify
+ * Libbrasero-media is free software; you can redistribute it and/or modify
+fy
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  * 
- * This program is distributed in the hope that it will be useful,
+ * Brasero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU Library General Public License for more details.
@@ -196,13 +197,10 @@ brasero_image_format_get_complement (BraseroImageFormat format,
 	gchar *retval = NULL;
 
 	if (format == BRASERO_IMAGE_FORMAT_CLONE) {
-		/* These are set rules no need to parse */
+		/* These are set rules no need to parse:
+		 * the toc file has to end with .toc suffix */
 		if (g_str_has_suffix (path, ".toc"))
-			retval = g_strdup_printf ("%.*sraw",
-						  strlen (path) - 3,
-						  path);
-		else
-			retval = g_strdup_printf ("%s.raw", path);
+			retval = g_strndup (path, strlen (path) - 4);
 	}
 	else if (format == BRASERO_IMAGE_FORMAT_CUE) {
 		/* need to parse */
@@ -304,16 +302,18 @@ stat_end:
 	g_free (path);
 
 	if (res == -1) {
+                int errsv = errno;
+
 		g_set_error (error,
 			     BRASERO_BURN_ERR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("size can't be retrieved (%s)"),
-			     strerror (errno));
+			     _("The size could not be retrieved (%s)"),
+			     g_strerror (errsv));
 		return FALSE;
 	}
 
 	if (size)
-		*size = BRASERO_SIZE_TO_SECTORS (buffer.st_size, 2352);
+		*size = BRASERO_BYTES_TO_SECTORS (buffer.st_size, 2352);
 
 	return TRUE;
 }
@@ -383,21 +383,24 @@ stat_end:
 		g_free (tmp);
 	}
 
-	/* if size is skipped then g_lstat () the file */
-	res = g_lstat (path, &buffer);
+	/* if size is skipped then g_stat () the file */
+	/* NOTE: follow symlink if any */
+	res = g_stat (path, &buffer);
 	g_free (path);
 
 	if (res == -1) {
+                int errsv = errno;
+
 		g_set_error (error,
 			     BRASERO_BURN_ERR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("size can't be retrieved (%s)"),
-			     strerror (errno));
+			     _("The size could not be retrieved (%s)"),
+			     g_strerror (errsv));
 		return FALSE;
 	}
 
 	if (size)
-		*size = BRASERO_SIZE_TO_SECTORS (buffer.st_size, 2352) - start;
+		*size = BRASERO_BYTES_TO_SECTORS (buffer.st_size, 2352) - start;
 
 	return TRUE;
 }
@@ -417,11 +420,13 @@ brasero_image_format_get_cdrdao_size (gchar *path,
 	 * multiple files. Which is great but not for us ... */
 	file = fopen (path, "r");
 	if (!file) {
+                int errsv = errno;
+
 		g_set_error (error,
 			     BRASERO_BURN_ERR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("size can't be retrieved (%s)"),
-			     strerror (errno));
+			     _("The size could not be retrieved (%s)"),
+			     g_strerror (errsv));
 		return FALSE;
 	}
 
@@ -544,11 +549,13 @@ brasero_image_format_get_cue_size (gchar *path,
 	 * multiple files. Which is great but not for us ... */
 	file = fopen (path, "r");
 	if (!file) {
+                int errsv = errno;
+
 		g_set_error (error,
 			     BRASERO_BURN_ERR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("size can't be retrieved (%s)"),
-			     strerror (errno));
+			     _("The size could not be retrieved (%s)"),
+			     g_strerror (errsv));
 		return FALSE;
 	}
 
@@ -583,15 +590,18 @@ brasero_image_format_get_cue_size (gchar *path,
 				g_free (tmp);
 			}
 
-			res = g_lstat (file_path, &buffer);
+			/* NOTE: follow symlink if any */
+			res = g_stat (file_path, &buffer);
 			if (res == -1) {
+                                int errsv = errno;
+
 				g_set_error (error,
 					     BRASERO_BURN_ERR,
 					     BRASERO_BURN_ERROR_GENERAL,
-					     _("size can't be retrieved for %s: %s"),
-					     file_path,
-					     strerror (errno));
+					     _("The size could not be retrieved (%s)"),
+					     g_strerror (errsv));
 				g_free (file_path);
+				fclose (file);
 				return FALSE;
 			}
 
@@ -640,11 +650,84 @@ brasero_image_format_get_cue_size (gchar *path,
 	if (size)
 		*size = cue_size;
 	if (blocks)
-		*blocks = BRASERO_SIZE_TO_SECTORS (cue_size, 2352);
+		*blocks = BRASERO_BYTES_TO_SECTORS (cue_size, 2352);
 
 	return TRUE;
 }
 
+BraseroImageFormat
+brasero_image_format_identify_cuesheet (const gchar *path)
+{
+	FILE *file;
+	BraseroImageFormat format;
+	gchar buffer [MAXPATHLEN * 2];
+
+	if (!path)
+		return BRASERO_IMAGE_FORMAT_NONE;
+
+	/* NOTE: the problem here is that cdrdao files can have references to 
+	 * multiple files. Which is great but not for us ... */
+	file = fopen (path, "r");
+	if (!file)
+		return BRASERO_IMAGE_FORMAT_NONE;
+
+	format = BRASERO_IMAGE_FORMAT_NONE;
+	while (fgets (buffer, sizeof (buffer), file)) {
+		/* Keywords for cdrdao cuesheets */
+		if (strstr (buffer, "CD_ROM_XA")
+		||  strstr (buffer, "CD_ROM")
+		||  strstr (buffer, "CD_DA")
+		||  strstr (buffer, "CD_TEXT")) {
+			format = BRASERO_IMAGE_FORMAT_CDRDAO;
+			break;
+		}
+		else if (strstr (buffer, "TRACK")) {
+			/* NOTE: there is also "AUDIO" but it's common to both */
+
+			/* CDRDAO */
+			if (strstr (buffer, "MODE1")
+			||  strstr (buffer, "MODE1_RAW")
+			||  strstr (buffer, "MODE2_FORM1")
+			||  strstr (buffer, "MODE2_FORM2")
+			||  strstr (buffer, "MODE_2_RAW")
+			||  strstr (buffer, "MODE2_FORM_MIX")
+			||  strstr (buffer, "MODE2")) {
+				format = BRASERO_IMAGE_FORMAT_CDRDAO;
+				break;
+			}
+
+			/* .CUE file */
+			else if (strstr (buffer, "CDG")
+			     ||  strstr (buffer, "MODE1/2048")
+			     ||  strstr (buffer, "MODE1/2352")
+			     ||  strstr (buffer, "MODE2/2336")
+			     ||  strstr (buffer, "MODE2/2352")
+			     ||  strstr (buffer, "CDI/2336")
+			     ||  strstr (buffer, "CDI/2352")) {
+				format = BRASERO_IMAGE_FORMAT_CUE;
+				break;
+			}
+		}
+		else if (strstr (buffer, "FILE")) {
+			if (strstr (buffer, "MOTOROLA")
+			||  strstr (buffer, "BINARY")
+			||  strstr (buffer, "AIFF")
+			||  strstr (buffer, "WAVE")
+			||  strstr (buffer, "MP3")) {
+				format = BRASERO_IMAGE_FORMAT_CUE;
+				break;
+			}
+		}
+	}
+	fclose (file);
+
+	BRASERO_BURN_LOG_WITH_FULL_TYPE (BRASERO_TRACK_TYPE_IMAGE,
+					 format,
+					 BRASERO_BURN_FLAG_NONE,
+					 "Detected");
+	return format;
+}
+
 gboolean
 brasero_image_format_get_iso_size (gchar *path,
 				   gint64 *blocks,
@@ -654,6 +737,9 @@ brasero_image_format_get_iso_size (gchar *path,
 	struct stat buffer;
 	int res;
 
+	if (!path)
+		return FALSE;
+
 	/* a simple stat () will do. That means of course that the image must be
 	 * local. Now if local-track is enabled, it will always run first and we
 	 * don't need that size before it starts. During the GET_SIZE phase of 
@@ -665,13 +751,16 @@ brasero_image_format_get_iso_size (gchar *path,
 	 * since it'll be local and stat() will work.
 	 * if local-track is not enabled we can't use non-local images anyway so
 	 * there is no need to have a function set_size */
-	res = g_lstat (path, &buffer);
+	/* NOTE: follow symlink if any */
+	res = g_stat (path, &buffer);
 	if (res == -1) {
+                int errsv = errno;
+
 		g_set_error (error,
 			     BRASERO_BURN_ERR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("size can't be retrieved (%s)"),
-			     strerror (errno));
+			     _("The size could not be retrieved (%s)"),
+			     g_strerror (errsv));
 
 		return FALSE;
 	}
@@ -706,13 +795,16 @@ brasero_image_format_get_clone_size (gchar *path,
 	 * since it'll be local and stat() will work.
 	 * if local-track is not enabled we can't use non-local images anyway so
 	 * there is no need to have a function set_size */
-	res = g_lstat (path, &buffer);
+	/* NOTE: follow symlink if any */
+	res = g_stat (path, &buffer);
 	if (res == -1) {
+                int errsv = errno;
+
 		g_set_error (error,
 			     BRASERO_BURN_ERR,
 			     BRASERO_BURN_ERROR_GENERAL,
-			     _("size can't be retrieved (%s)"),
-			     strerror (errno));
+			     _("The size could not be retrieved (%s)"),
+			     g_strerror (errsv));
 
 		return FALSE;
 	}
@@ -726,3 +818,101 @@ brasero_image_format_get_clone_size (gchar *path,
 
 	return TRUE;
 }
+
+gchar *
+brasero_image_format_get_default_path (BraseroImageFormat format)
+{
+	const gchar *suffixes [] = {".iso",
+				    ".toc",
+				    ".cue",
+				    ".toc",
+				    NULL };
+	const gchar *suffix = NULL;
+	gchar *path;
+	gint i = 0;
+
+	if (format & BRASERO_IMAGE_FORMAT_BIN)
+		suffix = suffixes [0];
+	else if (format & BRASERO_IMAGE_FORMAT_CLONE)
+		suffix = suffixes [1];
+	else if (format & BRASERO_IMAGE_FORMAT_CUE)
+		suffix = suffixes [2];
+	else if (format & BRASERO_IMAGE_FORMAT_CDRDAO)
+		suffix = suffixes [3];
+
+	path = g_strdup_printf ("%s/brasero%s",
+				g_get_home_dir (),
+				suffix);
+
+	while (g_file_test (path, G_FILE_TEST_EXISTS)) {
+		g_free (path);
+
+		path = g_strdup_printf ("%s/brasero-%i%s",
+					g_get_home_dir (),
+					i,
+					suffix);
+		i ++;
+	}
+
+	return path;
+}
+
+gchar *
+brasero_image_format_fix_path_extension (BraseroImageFormat format,
+					 gboolean check_existence,
+					 gchar *path)
+{
+	gchar *dot;
+	guint i = 0;
+	gchar *retval = NULL;
+	const gchar *suffix = NULL;;
+	const gchar *suffixes [] = {".iso",
+				    ".toc",
+				    ".cue",
+				    ".toc",
+				    NULL };
+
+	/* search the last dot to check extension */
+	dot = g_utf8_strrchr (path, -1, '.');
+	if (dot && strlen (dot) < 5 && strlen (dot) > 1) {
+		if (format & BRASERO_IMAGE_FORMAT_BIN
+		&&  strcmp (suffixes [0], dot))
+			*dot = '\0';
+		else if (format & BRASERO_IMAGE_FORMAT_CLONE
+		     &&  strcmp (suffixes [1], dot))
+			*dot = '\0';
+		else if (format & BRASERO_IMAGE_FORMAT_CUE
+		     &&  strcmp (suffixes [2], dot))
+			*dot = '\0';
+		else if (format & BRASERO_IMAGE_FORMAT_CDRDAO
+		     &&  strcmp (suffixes [3], dot))
+			*dot = '\0';
+		else
+			return g_strdup (path);
+	}
+
+	/* determine the proper suffix */
+	if (format & BRASERO_IMAGE_FORMAT_BIN)
+		suffix = suffixes [0];
+	else if (format & BRASERO_IMAGE_FORMAT_CLONE)
+		suffix = suffixes [1];
+	else if (format & BRASERO_IMAGE_FORMAT_CUE)
+		suffix = suffixes [2];
+	else if (format & BRASERO_IMAGE_FORMAT_CDRDAO)
+		suffix = suffixes [3];
+	else
+		return g_strdup (path);
+
+	/* make sure the file doesn't exist */
+	retval = g_strdup_printf ("%s%s", path, suffix);
+	if (!check_existence)
+		return retval;
+
+	while (g_file_test (retval, G_FILE_TEST_EXISTS)) {
+		g_free (retval);
+		retval = g_strdup_printf ("%s-%i%s", path, i, suffix);
+		i ++;
+	}
+
+	return retval;
+}
