@@ -31,12 +31,14 @@
 
 #include <gconf/gconf-client.h>
 
+#include "brasero-media-private.h"
+
 #include "burn-basics.h"
 #include "burn-debug.h"
 #include "burn-plugin.h"
 #include "burn-plugin-private.h"
 #include "burn-caps.h"
-#include "burn-media.h"
+#include "brasero-media.h"
 
 #define BRASERO_PLUGIN_PRIORITY_KEY			"/apps/brasero/config/priority"
 
@@ -948,13 +950,14 @@ brasero_plugin_priority_changed (GConfClient *client,
 	priv = BRASERO_PLUGIN_PRIVATE (self);
 
 	value = gconf_entry_get_value (entry);
-	if (value->type != GCONF_VALUE_INT)
+	if (!value)
+		priv->priority = 0;
+	else if (value->type != GCONF_VALUE_INT)
 		return;
-
-	self = BRASERO_PLUGIN (data);
+	else
+		priv->priority = gconf_value_get_int (value);
 
 	is_active = brasero_plugin_get_active (self);
-	priv->priority = gconf_value_get_int (value);
 
 	g_object_notify (G_OBJECT (self), "priority");
 	if (is_active != brasero_plugin_get_active (self))
