@@ -2,17 +2,18 @@
  *            burn-track.c
  *
  *  Thu Dec  7 09:50:38 2006
- *  Copyright  2006  algernon
- *  <algernon@localhost.localdomain>
+ *  Copyright  2006  Rouquier Philippe
+ *  <bonfire-app@wanadoo.fr>
  ****************************************************************************/
 
 /*
- * This program is free software; you can redistribute it and/or modify
+ * Libbrasero-media is free software; you can redistribute it and/or modify
+fy
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
  * 
- * This program is distributed in the hope that it will be useful,
+ * Brasero is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU Library General Public License for more details.
@@ -37,9 +38,9 @@
 
 #include "burn-track.h"
 #include "burn-debug.h"
-#include "burn-medium.h"
+#include "brasero-medium.h"
 #include "burn-image-format.h"
-#include "burn-drive.h"
+#include "brasero-drive.h"
 #include "burn-mkisofs-base.h"
 
 struct _BraseroTrack {
@@ -128,6 +129,9 @@ brasero_song_info_copy (BraseroSongInfo *info)
 {
 	BraseroSongInfo *copy;
 
+	if (!info)
+		return NULL;
+
 	copy = g_new0 (BraseroSongInfo, 1);
 
 	copy->title = g_strdup (info->title);
@@ -612,9 +616,6 @@ brasero_track_set_image_source (BraseroTrack *track,
 	if (track->type.type != BRASERO_TRACK_TYPE_IMAGE)
 		return BRASERO_BURN_NOT_SUPPORTED;
 
-	if (format == BRASERO_IMAGE_FORMAT_NONE)
-		return BRASERO_BURN_NOT_SUPPORTED;
-
 	track->type.subtype.img_format = format;
 
 	image = (BraseroTrackImage *) track;
@@ -922,10 +923,8 @@ brasero_track_set_checksum (BraseroTrack *track,
 	BraseroBurnResult result = BRASERO_BURN_OK;
 
 	if (type == track->checksum_type
-	&& (type == BRASERO_CHECKSUM_MD5
-	||  type == BRASERO_CHECKSUM_SHA1
-	||  type == BRASERO_CHECKSUM_SHA256)
-	&&  strcmp (checksum, track->checksum))
+	&& (type == BRASERO_CHECKSUM_MD5 || type == BRASERO_CHECKSUM_SHA1 || type == BRASERO_CHECKSUM_SHA256)
+	&&  checksum && strcmp (checksum, track->checksum))
 		result = BRASERO_BURN_ERR;
 
 	if (track->checksum)
@@ -943,7 +942,7 @@ brasero_track_set_checksum (BraseroTrack *track,
 const gchar *
 brasero_track_get_checksum (BraseroTrack *track)
 {
-	return track->checksum;
+	return track->checksum ? track->checksum : "";
 }
 
 BraseroChecksumType
@@ -1021,7 +1020,7 @@ brasero_track_get_image_size (BraseroTrack *track,
 
 	image = (BraseroTrackImage *) track;
 
-	/* Convienience function */
+	/* Convenience function */
 	if (track->type.subtype.img_format == BRASERO_IMAGE_FORMAT_BIN) {
 		gchar *path;
 
@@ -1041,10 +1040,10 @@ brasero_track_get_image_size (BraseroTrack *track,
 	else if (track->type.subtype.img_format == BRASERO_IMAGE_FORMAT_CLONE) {
 		gchar *path;
 
-		if (!image->image)
+		path = brasero_track_get_image_source (track, FALSE);
+		if (!path)
 			return BRASERO_BURN_ERR;
 
-		path = brasero_track_get_localpath (image->image);
 		if (!brasero_image_format_get_clone_size (path, blocks, size, error)) {
 			g_free (path);
 			return BRASERO_BURN_ERR;
@@ -1147,7 +1146,10 @@ brasero_track_tag_add (BraseroTrack *track,
 						     g_str_equal,
 						     g_free,
 						     brasero_track_tag_value_free);
-	g_hash_table_insert (track->tags, g_strdup (tag), value);
+	g_hash_table_insert (track->tags,
+			     g_strdup (tag),
+			     value);
+
 	return BRASERO_BURN_OK;
 }
 
