@@ -7,19 +7,21 @@
  ***************************************************************************/
 
 /*
- *  This program is free software; you can redistribute it and/or modify
+ *  Brasero is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 2 of the License, or
  *  (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Brasero is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Library General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  along with this program; if not, write to:
+ * 	The Free Software Foundation, Inc.,
+ * 	51 Franklin Street, Fifth Floor
+ * 	Boston, MA  02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -38,8 +40,6 @@
 #include <glib/gstdio.h>
 #include <gmodule.h>
 
-#include <nautilus-burn-drive.h>
-
 #include "burn-basics.h"
 #include "burn-debug.h"
 #include "burn-job.h"
@@ -61,7 +61,7 @@ static GObjectClass *parent_class = NULL;
 static BraseroBurnResult
 brasero_mkisofs_read_isosize (BraseroProcess *process, const gchar *line)
 {
-	gint sectors;
+	gint64 sectors;
 
 	sectors = strtoll (line, NULL, 10);
 	if (!sectors)
@@ -70,7 +70,7 @@ brasero_mkisofs_read_isosize (BraseroProcess *process, const gchar *line)
 	/* mkisofs reports blocks of 2048 bytes */
 	brasero_job_set_output_size_for_current_track (BRASERO_JOB (process),
 						       sectors,
-						       sectors * 2048);
+						       sectors * 2048ULL);
 	return BRASERO_BURN_OK;
 }
 
@@ -107,29 +107,27 @@ brasero_mkisofs_read_stderr (BraseroProcess *process, const gchar *line)
 	else if (strstr (line, "Input/output error. Read error on old image")) {
 		brasero_job_error (BRASERO_JOB (process), 
 				   g_error_new_literal (BRASERO_BURN_ERROR,
-							BRASERO_BURN_ERROR_GENERAL,
-							_("the old image couldn't be read")));
+							BRASERO_BURN_ERROR_IMAGE_LAST_SESSION,
+							_("Last session import failed")));
 	}
 	else if (strstr (line, "Unable to sort directory")) {
 		brasero_job_error (BRASERO_JOB (process), 
 				   g_error_new_literal (BRASERO_BURN_ERROR,
-							BRASERO_BURN_ERROR_GENERAL,
-							_("the image can't be created")));
+							BRASERO_BURN_ERROR_WRITE_IMAGE,
+							_("An image could not be created")));
 	}
-	else if (strstr (line, "have the same joliet name")) {
-		/* we keep the name of the files in case we need to rerun */
-	}
-	else if (strstr (line, "Joliet tree sort failed.")) {
+	else if (strstr (line, "have the same joliet name")
+	     ||  strstr (line, "Joliet tree sort failed.")) {
 		brasero_job_error (BRASERO_JOB (process), 
 				   g_error_new_literal (BRASERO_BURN_ERROR,
-							BRASERO_BURN_ERROR_JOLIET_TREE,
-							_("the image can't be created")));
+							BRASERO_BURN_ERROR_IMAGE_JOLIET,
+							_("An image could not be created")));
 	}
 	else if (strstr (line, "Use mkisofs -help")) {
 		brasero_job_error (BRASERO_JOB (process), 
 				   g_error_new_literal (BRASERO_BURN_ERROR,
-							BRASERO_BURN_ERROR_JOLIET_TREE,
-							_("this version of mkisofs doesn't seem to be supported")));
+							BRASERO_BURN_ERROR_GENERAL,
+							_("This version of mkisofs is not supported")));
 	}
 /*	else if ((pos =  strstr (line,"mkisofs: Permission denied. "))) {
 		int res = FALSE;
@@ -156,7 +154,7 @@ brasero_mkisofs_read_stderr (BraseroProcess *process, const gchar *line)
 		else
 			return TRUE;
 
-		res = brasero_mkisofs_base_ask_unreadable_file (BRASERO_MKISOFS_BASE (process),
+		res = brasero_mkisofs_base_ask_unreadable_file (BRASERO_GENISOIMAGE_BASE (process),
 								path,
 								isdir);
 		if (!res) {
@@ -170,34 +168,52 @@ brasero_mkisofs_read_stderr (BraseroProcess *process, const gchar *line)
 	else if (strstr (line, "Incorrectly encoded string")) {
 		brasero_job_error (BRASERO_JOB (process),
 				   g_error_new_literal (BRASERO_BURN_ERROR,
-							BRASERO_BURN_ERROR_JOLIET_TREE,
+							BRASERO_BURN_ERROR_INPUT_INVALID,
 							_("Some files have invalid filenames")));
 	}
 	else if (strstr (line, "Unknown charset")) {
 		brasero_job_error (BRASERO_JOB (process),
 				   g_error_new_literal (BRASERO_BURN_ERROR,
-							BRASERO_BURN_ERROR_GENERAL,
+							BRASERO_BURN_ERROR_INPUT_INVALID,
 							_("Unknown character encoding")));
 	}
-	else if (strstr (line, "Resource temporarily unavailable")) {
-		brasero_job_error (BRASERO_JOB (process),
-				   g_error_new_literal (BRASERO_BURN_ERROR,
-							BRASERO_BURN_ERROR_GENERAL,
-							_("writing to file descriptor failed")));
-	}
 	else if (strstr (line, "No space left on device")) {
 		brasero_job_error (BRASERO_JOB (process),
 				   g_error_new_literal (BRASERO_BURN_ERROR,
 							BRASERO_BURN_ERROR_DISK_SPACE,
 							_("There is no space left on the device")));
+
 	}
-	else if (strstr (line, "Value too large for defined data type")) {
-		/* TODO: get filename from error message */
+	else if (strstr (line, "Unable to open disc image file")) {
 		brasero_job_error (BRASERO_JOB (process),
 				   g_error_new_literal (BRASERO_BURN_ERROR,
-							BRASERO_BURN_ERROR_GENERAL,
-							_("The file is too large for a CD")));
+							BRASERO_BURN_ERROR_PERMISSION,
+							_("You do not have the required permission to write at this location")));
+
 	}
+	else if (strstr (line, "Value too large for defined data type")) {
+		brasero_job_error (BRASERO_JOB (process),
+				   g_error_new_literal (BRASERO_BURN_ERROR,
+							BRASERO_BURN_ERROR_MEDIUM_SPACE,
+							_("Not enough space available on the disc")));
+	}
+
+	/** REMINDER: these should not be necessary
+
+	else if (strstr (line, "Resource temporarily unavailable")) {
+		brasero_job_error (BRASERO_JOB (process),
+				   g_error_new_literal (BRASERO_BURN_ERROR,
+							BRASERO_BURN_ERROR_INPUT,
+							_("Data could not be written")));
+	}
+	else if (strstr (line, "Bad file descriptor.")) {
+		brasero_job_error (BRASERO_JOB (process),
+				   g_error_new_literal (BRASERO_BURN_ERROR,
+							BRASERO_BURN_ERROR_INPUT,
+							_("Internal error: bad file descriptor")));
+	}
+
+	**/
 
 	return BRASERO_BURN_OK;
 }
@@ -211,6 +227,7 @@ brasero_mkisofs_set_argv_image (BraseroMkisofs *mkisofs,
 	BraseroTrack *track;
 	BraseroTrackType type;
 	BraseroBurnFlag flags;
+	gchar *videodir = NULL;
 	gchar *emptydir = NULL;
 	BraseroJobAction action;
 	BraseroBurnResult result;
@@ -225,21 +242,41 @@ brasero_mkisofs_set_argv_image (BraseroMkisofs *mkisofs,
 		BRASERO_JOB_NOT_READY (mkisofs);
 
 	brasero_track_get_type (track, &type);
-	if ((type.subtype.fs_type & BRASERO_IMAGE_FS_JOLIET))
+	if (type.subtype.fs_type & BRASERO_IMAGE_FS_JOLIET)
 		g_ptr_array_add (argv, g_strdup ("-J"));
 
-	if ((type.subtype.fs_type & BRASERO_IMAGE_FS_VIDEO))
+	if ((type.subtype.fs_type & BRASERO_IMAGE_FS_ISO)
+	&&  (type.subtype.fs_type & BRASERO_IMAGE_ISO_FS_LEVEL_3)) {
+		g_ptr_array_add (argv, g_strdup ("-iso-level"));
+		g_ptr_array_add (argv, g_strdup ("3"));
+	}
+
+	if (type.subtype.fs_type & BRASERO_IMAGE_FS_UDF)
+		g_ptr_array_add (argv, g_strdup ("-udf"));
+
+	if (type.subtype.fs_type & BRASERO_IMAGE_FS_VIDEO) {
 		g_ptr_array_add (argv, g_strdup ("-dvd-video"));
 
+		result = brasero_job_get_tmp_dir (BRASERO_JOB (mkisofs),
+						  &videodir,
+						  error);
+		if (result != BRASERO_BURN_OK)
+			return result;
+	}
+
 	g_ptr_array_add (argv, g_strdup ("-graft-points"));
-	g_ptr_array_add (argv, g_strdup ("-D"));	// This is dangerous the manual says but apparently it works well
+
+	if (type.subtype.fs_type & BRASERO_IMAGE_ISO_FS_DEEP_DIRECTORY)
+		g_ptr_array_add (argv, g_strdup ("-D"));	// This is dangerous the manual says but apparently it works well
 
 	result = brasero_job_get_tmp_file (BRASERO_JOB (mkisofs),
 					   NULL,
 					   &grafts_path,
 					   error);
-	if (result != BRASERO_BURN_OK)
+	if (result != BRASERO_BURN_OK) {
+		g_free (videodir);
 		return result;
+	}
 
 	result = brasero_job_get_tmp_file (BRASERO_JOB (mkisofs),
 					   NULL,
@@ -247,6 +284,7 @@ brasero_mkisofs_set_argv_image (BraseroMkisofs *mkisofs,
 					   error);
 	if (result != BRASERO_BURN_OK) {
 		g_free (grafts_path);
+		g_free (videodir);
 		return result;
 	}
 
@@ -254,6 +292,7 @@ brasero_mkisofs_set_argv_image (BraseroMkisofs *mkisofs,
 					  &emptydir,
 					  error);
 	if (result != BRASERO_BURN_OK) {
+		g_free (videodir);
 		g_free (grafts_path);
 		g_free (excluded_path);
 		return result;
@@ -263,10 +302,12 @@ brasero_mkisofs_set_argv_image (BraseroMkisofs *mkisofs,
 					       grafts_path,
 					       excluded_path,
 					       emptydir,
+					       videodir,
 					       error);
 	g_free (emptydir);
 
 	if (result != BRASERO_BURN_OK) {
+		g_free (videodir);
 		g_free (grafts_path);
 		g_free (excluded_path);
 		return result;
@@ -278,19 +319,6 @@ brasero_mkisofs_set_argv_image (BraseroMkisofs *mkisofs,
 	g_ptr_array_add (argv, g_strdup ("-exclude-list"));
 	g_ptr_array_add (argv, excluded_path);
 
-	brasero_job_get_action (BRASERO_JOB (mkisofs), &action);
-	if (action == BRASERO_JOB_ACTION_SIZE) {
-		g_ptr_array_add (argv, g_strdup ("-quiet"));
-		g_ptr_array_add (argv, g_strdup ("-print-size"));
-
-		brasero_job_set_current_action (BRASERO_JOB (mkisofs),
-						BRASERO_BURN_ACTION_GETTING_SIZE,
-						NULL,
-						FALSE);
-		brasero_job_start_progress (BRASERO_JOB (mkisofs), FALSE);
-		return BRASERO_BURN_OK;
-	}
-
 	brasero_job_get_data_label (BRASERO_JOB (mkisofs), &label);
 	if (label) {
 		g_ptr_array_add (argv, g_strdup ("-V"));
@@ -304,7 +332,11 @@ brasero_mkisofs_set_argv_image (BraseroMkisofs *mkisofs,
 						BRASERO_SUB));
 	
 	g_ptr_array_add (argv, g_strdup ("-sysid"));
+#if defined(HAVE_STRUCT_USCSI_CMD)
+	g_ptr_array_add (argv, g_strdup ("SOLARIS"));
+#else
 	g_ptr_array_add (argv, g_strdup ("LINUX"));
+#endif
 	
 	/* FIXME! -sort is an interesting option allowing to decide where the 
 	* files are written on the disc and therefore to optimize later reading */
@@ -320,10 +352,12 @@ brasero_mkisofs_set_argv_image (BraseroMkisofs *mkisofs,
 		brasero_job_get_last_session_address (BRASERO_JOB (mkisofs), &last_session);
 		brasero_job_get_next_writable_address (BRASERO_JOB (mkisofs), &next_wr_add);
 		if (last_session == -1 || next_wr_add == -1) {
+			g_free (videodir);
+			BRASERO_JOB_LOG (mkisofs, "Failed to get the start point of the track. Make sure the media allow to add files (it is not closed)"); 
 			g_set_error (error,
 				     BRASERO_BURN_ERROR,
 				     BRASERO_BURN_ERROR_GENERAL,
-				     _("failed to get the start point of the track. Make sure the media allow to add files (it is not closed)"));
+				     _("An internal error occured"));
 			return BRASERO_BURN_ERR;
 		}
 
@@ -339,24 +373,56 @@ brasero_mkisofs_set_argv_image (BraseroMkisofs *mkisofs,
 
 			g_ptr_array_add (argv, g_strdup ("-M"));
 
+#ifdef HAVE_CAM_LIB_H
+	/* FreeBSD like that better */
+			brasero_job_get_bus_target_lun (BRASERO_JOB (mkisofs), &device);
+#else
 			brasero_job_get_device (BRASERO_JOB (mkisofs), &device);
+#endif
+
 			g_ptr_array_add (argv, device);
 		}
 	}
 
+	brasero_job_get_action (BRASERO_JOB (mkisofs), &action);
+	if (action == BRASERO_JOB_ACTION_SIZE) {
+		g_ptr_array_add (argv, g_strdup ("-quiet"));
+		g_ptr_array_add (argv, g_strdup ("-print-size"));
+
+		brasero_job_set_current_action (BRASERO_JOB (mkisofs),
+						BRASERO_BURN_ACTION_GETTING_SIZE,
+						NULL,
+						FALSE);
+		brasero_job_start_progress (BRASERO_JOB (mkisofs), FALSE);
+
+		if (videodir) {
+			g_ptr_array_add (argv, g_strdup ("-f"));
+			g_ptr_array_add (argv, videodir);
+		}
+
+		return BRASERO_BURN_OK;
+	}
+
 	if (brasero_job_get_fd_out (BRASERO_JOB (mkisofs), NULL) != BRASERO_BURN_OK) {
 		gchar *output = NULL;
 
 		result = brasero_job_get_image_output (BRASERO_JOB (mkisofs),
 						      &output,
 						       NULL);
-		if (result != BRASERO_BURN_OK)
+		if (result != BRASERO_BURN_OK) {
+			g_free (videodir);
 			return result;
+		}
 
 		g_ptr_array_add (argv, g_strdup ("-o"));
 		g_ptr_array_add (argv, output);
 	}
 
+	if (videodir) {
+		g_ptr_array_add (argv, g_strdup ("-f"));
+		g_ptr_array_add (argv, videodir);
+	}
+
 	brasero_job_set_current_action (BRASERO_JOB (mkisofs),
 					BRASERO_BURN_ACTION_CREATING_IMAGE,
 					NULL,
@@ -450,32 +516,28 @@ brasero_mkisofs_finalize (GObject *object)
 static BraseroBurnResult
 brasero_mkisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 {
-	gchar *prog_name;
+	BraseroBurnResult result;
 	GSList *output;
 	GSList *input;
 
 	brasero_plugin_define (plugin,
 			       "mkisofs",
-			       _("use mkisofs to create images from files"),
+			       _("Use mkisofs to create image from a file selection"),
 			       "Philippe Rouquier",
 			       0);
 
-	/* First see if this plugin can be used, i.e. if mkisofs is in
-	 * the path */
-	prog_name = g_find_program_in_path ("mkisofs");
-	if (!prog_name) {
-		*error = g_strdup (_("mkisofs could not be found in the path"));
-		return BRASERO_BURN_ERR;
-	}
-	g_free (prog_name);
+	/* First see if this plugin can be used */
+	result = brasero_process_check_path ("mkisofs", error);
+	if (result != BRASERO_BURN_OK)
+		return result;
 
-	/* NOTE: we don't include DVDRW+ DVDRW- restricted in here */
 	brasero_plugin_set_flags (plugin,
 				  BRASERO_MEDIUM_CDR|
 				  BRASERO_MEDIUM_CDRW|
 				  BRASERO_MEDIUM_DVDR|
 				  BRASERO_MEDIUM_DVDRW|
 				  BRASERO_MEDIUM_DVDR_PLUS|
+				  BRASERO_MEDIUM_DUAL_L|
 				  BRASERO_MEDIUM_APPENDABLE|
 				  BRASERO_MEDIUM_HAS_AUDIO|
 				  BRASERO_MEDIUM_HAS_DATA,
@@ -483,7 +545,21 @@ brasero_mkisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 				  BRASERO_BURN_FLAG_MERGE,
 				  BRASERO_BURN_FLAG_NONE);
 
+	brasero_plugin_set_flags (plugin,
+				  BRASERO_MEDIUM_DUAL_L|
+				  BRASERO_MEDIUM_DVDRW_PLUS|
+				  BRASERO_MEDIUM_RESTRICTED|
+				  BRASERO_MEDIUM_APPENDABLE|
+				  BRASERO_MEDIUM_CLOSED|
+				  BRASERO_MEDIUM_HAS_DATA,
+				  BRASERO_BURN_FLAG_APPEND|
+				  BRASERO_BURN_FLAG_MERGE,
+				  BRASERO_BURN_FLAG_NONE);
+
 	input = brasero_caps_data_new (BRASERO_IMAGE_FS_ISO|
+				       BRASERO_IMAGE_FS_UDF|
+				       BRASERO_IMAGE_ISO_FS_LEVEL_3|
+				       BRASERO_IMAGE_ISO_FS_DEEP_DIRECTORY|
 				       BRASERO_IMAGE_FS_JOLIET|
 				       BRASERO_IMAGE_FS_VIDEO);
 
