@@ -47,13 +47,15 @@
 #include "burn-dvdcss.h"
 #include "burn-dvdcss-private.h"
 #include "burn-volume.h"
-#include "burn-medium.h"
+#include "brasero-medium.h"
 
 BRASERO_PLUGIN_BOILERPLATE (BraseroDvdcss, brasero_dvdcss, BRASERO_TYPE_JOB, BraseroJob);
 
 struct _BraseroDvdcssPrivate {
 	GError *error;
 	GThread *thread;
+	GMutex *mutex;
+	GCond *cond;
 	guint thread_id;
 
 	guint cancel:1;
@@ -117,14 +119,14 @@ error_doesnt_exist:
 	g_set_error (error,
 		     BRASERO_BURN_ERROR,
 		     BRASERO_BURN_ERROR_GENERAL,
-		     _("Encrypted DVD: please, install libdvdcss version 1.2.x"));
+		     _("Encrypted DVD: please install libdvdcss version 1.2.x"));
 	return FALSE;
 
 error_version:
 	g_set_error (error,
 		     BRASERO_BURN_ERROR,
 		     BRASERO_BURN_ERROR_GENERAL,
-		     _("Libdvdcss version %s is not supported.\nPlease, install libdvdcss version 1.2.x"),
+		     _("Libdvdcss version %s is not supported.\nPlease install libdvdcss version 1.2.x"),
 		     dvdcss_interface_2);
 	g_module_close (module);
 	return FALSE;
@@ -263,7 +265,7 @@ brasero_dvdcss_create_scrambled_sectors_map (GQueue *map,
 
 					extent = extents->data;
 					range->start = extent->block;
-					range->end = extent->block + BRASERO_SIZE_TO_SECTORS (extent->size, DVDCSS_BLOCK_SIZE);
+					range->end = extent->block + BRASERO_BYTES_TO_SECTORS (extent->size, DVDCSS_BLOCK_SIZE);
 
 					g_queue_push_head (map, range);
 
@@ -504,7 +506,12 @@ end:
 	if (!priv->cancel)
 		priv->thread_id = g_idle_add (brasero_dvdcss_thread_finished, self);
 
+	/* End thread */
+	g_mutex_lock (priv->mutex);
 	priv->thread = NULL;
+	g_cond_signal (priv->cond);
+	g_mutex_unlock (priv->mutex);
+
 	g_thread_exit (NULL);
 
 	return NULL;
@@ -543,10 +550,12 @@ brasero_dvdcss_start (BraseroJob *job,
 	if (!brasero_dvdcss_library_init (error))
 		return BRASERO_BURN_ERR;
 
+	g_mutex_lock (priv->mutex);
 	priv->thread = g_thread_create (brasero_dvdcss_write_image_thread,
 					self,
 					TRUE,
 					error);
+	g_mutex_unlock (priv->mutex);
 
 	if (!priv->thread)
 		return BRASERO_BURN_ERR;
@@ -560,11 +569,14 @@ brasero_dvdcss_stop_real (BraseroDvdcss *self)
 	BraseroDvdcssPrivate *priv;
 
 	priv = BRASERO_DVDCSS_PRIVATE (self);
+
+	g_mutex_lock (priv->mutex);
 	if (priv->thread) {
 		priv->cancel = 1;
-		g_thread_join (priv->thread);
+		g_cond_wait (priv->cond, priv->mutex);
 		priv->cancel = 0;
 	}
+	g_mutex_unlock (priv->mutex);
 
 	if (priv->thread_id) {
 		g_source_remove (priv->thread_id);
@@ -606,12 +618,34 @@ brasero_dvdcss_class_init (BraseroDvdcssClass *klass)
 
 static void
 brasero_dvdcss_init (BraseroDvdcss *obj)
-{ }
+{
+	BraseroDvdcssPrivate *priv;
+
+	priv = BRASERO_DVDCSS_PRIVATE (obj);
+
+	priv->mutex = g_mutex_new ();
+	priv->cond = g_cond_new ();
+}
 
 static void
 brasero_dvdcss_finalize (GObject *object)
 {
+	BraseroDvdcssPrivate *priv;
+
+	priv = BRASERO_DVDCSS_PRIVATE (object);
+
 	brasero_dvdcss_stop_real (BRASERO_DVDCSS (object));
+
+	if (priv->mutex) {
+		g_mutex_free (priv->mutex);
+		priv->mutex = NULL;
+	}
+
+	if (priv->cond) {
+		g_cond_free (priv->cond);
+		priv->cond = NULL;
+	}
+
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
