@@ -7,19 +7,22 @@
  ***************************************************************************/
 
 /*
- *  This program is free software; you can redistribute it and/or modify
+ *  Brasero is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version  of the License, or
  *  (at your option) any later version.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  Brasero is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU Library General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite , Boston, MA 111-17, USA.
+ *  along with this program; if not, write to:
+ * 	The Free Software Foundation, Inc.,
+ * 	51 Franklin Street, Fifth Floor
+ * 	Boston, MA  02110-1301, USA.t, Fifth Floor
+ * 	Boston, MA  02110-1301, USA., Boston, MA 111-17, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -37,19 +40,22 @@
 
 #include <gmodule.h>
 
+#include <gconf/gconf-client.h> 
+
 #include "burn-basics.h"
 #include "burn-plugin.h"
 #include "burn-job.h"
 #include "burn-process.h"
-#include "burn-drive.h"
+#include "brasero-drive.h"
 #include "burn-growisofs.h"
 #include "burn-growisofs-common.h"
 
 BRASERO_PLUGIN_BOILERPLATE (BraseroGrowisofs, brasero_growisofs, BRASERO_TYPE_PROCESS, BraseroProcess);
 
 struct BraseroGrowisofsPrivate {
-	gint64 sectors_num;
 	guint use_utf8:1;
+	guint use_genisoimage:1;
+  	guint use_dao:1;
 };
 typedef struct BraseroGrowisofsPrivate BraseroGrowisofsPrivate;
 
@@ -57,6 +63,8 @@ typedef struct BraseroGrowisofsPrivate BraseroGrowisofsPrivate;
 
 static GObjectClass *parent_class = NULL;
 
+#define GCONF_KEY_DAO_FLAG "/apps/brasero/config/dao_flag" 
+
 /* Process start */
 static BraseroBurnResult
 brasero_growisofs_read_stdout (BraseroProcess *process, const gchar *line)
@@ -65,13 +73,14 @@ brasero_growisofs_read_stdout (BraseroProcess *process, const gchar *line)
 	int speed_1, speed_2;
 	long long b_written, b_total;
 
-	if (sscanf (line, "%10lld/%lld (%2d.%1d%%) @%2d.%1dx, remaining %*d:%*d",
+	/* Newer growisofs version have a different line pattern that shows
+	 * drive buffer filling. */
+	if (sscanf (line, "%10lld/%lld (%4d.%1d%%) @%2d.%1dx, remaining %*d:%*d",
 		    &b_written, &b_total, &perc_1, &perc_2, &speed_1, &speed_2) == 6) {
 		BraseroJobAction action;
 
 		brasero_job_get_action (BRASERO_JOB (process), &action);
-		if (action == BRASERO_JOB_ACTION_ERASE
-		&&  b_written >= 65536) {
+		if (action == BRASERO_JOB_ACTION_ERASE && b_written >= 65536) {
 			/* we nullified 65536 that's enough. A signal SIGTERM
 			 * will be sent in process.c. That's not the best way
 			 * to do it but it works. */
@@ -107,12 +116,12 @@ brasero_growisofs_read_stderr (BraseroProcess *process, const gchar *line)
 {
 	int perc_1, perc_2;
 
-	if (sscanf (line, " %2d.%1d%% done, estimate finish", &perc_1, &perc_2) == 2) {
+	if (sscanf (line, " %2d.%2d%% done, estimate finish", &perc_1, &perc_2) == 2) {
 		gdouble fraction;
 		BraseroBurnAction action;
 
 		fraction = (gdouble) ((gdouble) perc_1 +
-			   ((gdouble) perc_2 / (gdouble) 10.0)) /
+			   ((gdouble) perc_2 / (gdouble) 100.0)) /
 			   (gdouble) 100.0;
 
 		brasero_job_set_progress (BRASERO_JOB (process), fraction);
@@ -120,8 +129,10 @@ brasero_growisofs_read_stderr (BraseroProcess *process, const gchar *line)
 		brasero_job_get_current_action (BRASERO_JOB (process), &action);
 		if (action == BRASERO_BURN_ACTION_BLANKING
 		&&  fraction >= 0.01) {
-			/* we nullified 1% (more than 65536) that's enough. A 
-			 * signal SIGTERM will be sent. */
+			/* we nullified 1% of the medium (more than 65536)
+			 * that's enough to make the filesystem unusable and
+			 * looking blank. A signal SIGTERM will be sent to stop
+			 * us. */
 			brasero_job_finished_session (BRASERO_JOB (process));
 			return BRASERO_BURN_OK;
 		}
@@ -145,7 +156,7 @@ brasero_growisofs_read_stderr (BraseroProcess *process, const gchar *line)
 			/* NOTE: this has to be a multiple of 2048 */
 			brasero_job_set_output_size_for_current_track (BRASERO_JOB (process),
 								       sectors,
-								       sectors * 2048);
+								       sectors * 2048ULL);
 
 			/* we better tell growisofs to stop here as it returns 
 			 * a value of 1 when mkisofs is run with --print-size */
@@ -159,62 +170,65 @@ brasero_growisofs_read_stderr (BraseroProcess *process, const gchar *line)
 						NULL,
 						FALSE);
 	}
-	else if (strstr (line, "already carries isofs") && strstr (line, "FATAL:")) {
-		brasero_job_error (BRASERO_JOB (process), 
-				   g_error_new (BRASERO_BURN_ERROR,
-						BRASERO_BURN_ERROR_MEDIA_NOT_WRITABLE,
-						_("The disc is already burnt")));
-	}
 	else if (strstr (line, "unable to open")
-	     ||  strstr (line, "unable to stat")) {
-		brasero_job_error (BRASERO_JOB (process), 
-				   g_error_new (BRASERO_BURN_ERROR,
-						BRASERO_BURN_ERROR_BUSY_DRIVE,
-						_("The recorder could not be accessed")));
-	}
-	else if (strstr (line, "not enough space available") != NULL) {
-		brasero_job_error (BRASERO_JOB (process), 
-				   g_error_new (BRASERO_BURN_ERROR,
-						BRASERO_BURN_ERROR_GENERAL,
-						_("Not enough space available on the disc")));
-	}
-	else if (strstr (line, "end of user area encountered on this track") != NULL) {
-		brasero_job_error (BRASERO_JOB (process), 
-				   g_error_new (BRASERO_BURN_ERROR,
-						BRASERO_BURN_ERROR_GENERAL,
-						_("The files selected did not fit on the CD")));
-	}
-	else if (strstr (line, "blocks are free") != NULL) {
-		brasero_job_error (BRASERO_JOB (process), 
-				   g_error_new (BRASERO_BURN_ERROR,
-						BRASERO_BURN_ERROR_GENERAL,
-						_("The files selected did not fit on the CD")));
-	}
-	else if (strstr (line, "unable to proceed with recording: unable to unmount")) {
+	     ||  strstr (line, "unable to stat")
+	     ||  strstr (line, "unable to proceed with recording: unable to unmount")) {
 		brasero_job_error (BRASERO_JOB (process),
 				   g_error_new_literal (BRASERO_BURN_ERROR,
-							BRASERO_BURN_ERROR_JOLIET_TREE,
-							_("the drive seems to be busy")));
+							BRASERO_BURN_ERROR_DRIVE_BUSY,
+							_("The drive is busy")));
 	}
-	else if (strstr (line, ":-(") != NULL || strstr (line, "FATAL")) {
+	else if (strstr (line, "not enough space available")
+	     ||  strstr (line, "end of user area encountered on this track")
+	     ||  strstr (line, "blocks are free")) {
 		brasero_job_error (BRASERO_JOB (process), 
 				   g_error_new (BRASERO_BURN_ERROR,
-						BRASERO_BURN_ERROR_GENERAL,
-						_("Unhandled error, aborting")));
+						BRASERO_BURN_ERROR_MEDIUM_SPACE,
+						_("Not enough space available on the disc")));
+	}
+	else if (strstr (line, "Input/output error. Read error on old image")) {
+		brasero_job_error (BRASERO_JOB (process), 
+				   g_error_new_literal (BRASERO_BURN_ERROR,
+							BRASERO_BURN_ERROR_IMAGE_LAST_SESSION,
+							_("Last session import failed")));
+	}
+	else if (strstr (line, "Unable to sort directory")) {
+		brasero_job_error (BRASERO_JOB (process), 
+				   g_error_new_literal (BRASERO_BURN_ERROR,
+							BRASERO_BURN_ERROR_WRITE_IMAGE,
+							_("An image could not be created")));
+	}
+	else if (strstr (line, "have the same joliet name")
+	     ||  strstr (line, "Joliet tree sort failed.")) {
+		brasero_job_error (BRASERO_JOB (process), 
+				   g_error_new_literal (BRASERO_BURN_ERROR,
+							BRASERO_BURN_ERROR_IMAGE_JOLIET,
+							_("An image could not be created")));
 	}
 	else if (strstr (line, "Incorrectly encoded string")) {
 		brasero_job_error (BRASERO_JOB (process),
 				   g_error_new_literal (BRASERO_BURN_ERROR,
-							BRASERO_BURN_ERROR_JOLIET_TREE,
+							BRASERO_BURN_ERROR_INPUT_INVALID,
 							_("Some files have invalid filenames")));
 	}
-	else if (strstr (line, "Joliet tree sort failed.")) {
-		brasero_job_error (BRASERO_JOB (process), 
+	else if (strstr (line, "Unknown charset")) {
+		brasero_job_error (BRASERO_JOB (process),
 				   g_error_new_literal (BRASERO_BURN_ERROR,
-							BRASERO_BURN_ERROR_JOLIET_TREE,
-							_("the image can't be created")));
+							BRASERO_BURN_ERROR_INPUT_INVALID,
+							_("Unknown character encoding")));
 	}
 
+	/** REMINDER! removed messages:
+	   else if (strstr (line, ":-(") != NULL || strstr (line, "FATAL"))
+
+	   else if (strstr (line, "already carries isofs") && strstr (line, "FATAL:")) {
+		brasero_job_error (BRASERO_JOB (process), 
+				   g_error_new (BRASERO_BURN_ERROR,
+						BRASERO_BURN_ERROR_MEDIUM_INVALID,
+						_("The disc is already burnt")));
+	   }
+	**/
+
 	return BRASERO_BURN_OK;
 }
 
@@ -233,6 +247,15 @@ brasero_growisofs_set_mkisofs_argv (BraseroGrowisofs *growisofs,
 	gchar *emptydir = NULL;
 	gchar *videodir = NULL;
 
+	priv = BRASERO_GROWISOFS_PRIVATE (growisofs);
+
+	if (priv->use_genisoimage) {
+		BRASERO_JOB_LOG (growisofs, "Using genisoimage");
+	}
+	else {
+		BRASERO_JOB_LOG (growisofs, "Using mkisofs");
+	}
+
 	g_ptr_array_add (argv, g_strdup ("-r"));
 
 	brasero_job_get_current_track (BRASERO_JOB (growisofs), &track);
@@ -247,6 +270,13 @@ brasero_growisofs_set_mkisofs_argv (BraseroGrowisofs *growisofs,
 		 * like MacOSX and freebsd.*/
 		g_ptr_array_add (argv, g_strdup ("-iso-level"));
 		g_ptr_array_add (argv, g_strdup ("3"));
+
+		/* NOTE: the following is specific to genisoimage
+		 * It allows to burn files over 4 GiB.
+		 * The only problem here is which are we using? mkisofs or
+		 * genisoimage? That's what we determined first. */
+		if (priv->use_genisoimage)
+			g_ptr_array_add (argv, g_strdup ("-allow-limited-size"));
 	}
 
 	if (input.subtype.fs_type & BRASERO_IMAGE_FS_UDF)
@@ -262,7 +292,6 @@ brasero_growisofs_set_mkisofs_argv (BraseroGrowisofs *growisofs,
 			return result;
 	}
 
-	priv = BRASERO_GROWISOFS_PRIVATE (growisofs);
 	if (priv->use_utf8) {
 		g_ptr_array_add (argv, g_strdup ("-input-charset"));
 		g_ptr_array_add (argv, g_strdup ("utf8"));
@@ -395,7 +424,9 @@ brasero_growisofs_set_argv_record (BraseroGrowisofs *growisofs,
 	 * DVD+-R. It will close the disc. Which make sense since DAO means
 	 * Disc At Once. That's checked in burn-caps.c with coherency checks.
 	 * NOTE 2: dao is supported for DL DVD after 6.0 (think about that for
-	 * BurnCaps) */
+	 * BurnCaps)
+	 * Moreover even for single session DVDs it doesn't work properly so
+	 * there is a workaround to turn it off entirely. */
 	if (flags & BRASERO_BURN_FLAG_DAO)
 		g_ptr_array_add (argv, g_strdup ("-use-the-force-luke=dao"));
 
@@ -458,8 +489,9 @@ brasero_growisofs_set_argv_record (BraseroGrowisofs *growisofs,
 			if (!g_file_test ("/proc/self/fd/0", G_FILE_TEST_EXISTS)) {
 				g_set_error (error,
 					     BRASERO_BURN_ERROR,
-					     BRASERO_BURN_ERROR_GENERAL,
-					     _("the file /proc/self/fd/0 is missing"));
+					     BRASERO_BURN_ERROR_FILE_NOT_FOUND,
+					     _("\"%s\" could not be found"),
+					     "/proc/self/fd/0");
 				return BRASERO_BURN_ERR;
 			}
 
@@ -477,8 +509,8 @@ brasero_growisofs_set_argv_record (BraseroGrowisofs *growisofs,
 			if (!localpath) {
 				g_set_error (error,
 					     BRASERO_BURN_ERROR,
-					     BRASERO_BURN_ERROR_GENERAL,
-					     _("the image is not stored locally"));
+					     BRASERO_BURN_ERROR_FILE_NOT_LOCAL,
+					     _("The file is not stored locally"));
 				return BRASERO_BURN_ERR;
 			}
 
@@ -622,22 +654,53 @@ static void
 brasero_growisofs_init (BraseroGrowisofs *obj)
 {
 	BraseroGrowisofsPrivate *priv;
-	gchar *standard_error;
-	gboolean res;
+	gchar *standard_error = NULL;
 	gchar *prog_name;
+	gboolean res;
 
 	priv = BRASERO_GROWISOFS_PRIVATE (obj);
 
-	/* this code comes from ncb_mkisofs_supports_utf8 */
-	
-	prog_name = g_find_program_in_path ("genisoimage");
-        if (prog_name && g_file_test (prog_name, G_FILE_TEST_IS_EXECUTABLE)) {
-	  	res = g_spawn_command_line_sync ("genisoimage -input-charset utf8", NULL, &standard_error, NULL, NULL);
-	} else {
-                res = g_spawn_command_line_sync ("mkisofs -input-charset utf8", NULL, &standard_error, NULL, NULL);
-	}
+	/* this code (remotely) comes from ncb_mkisofs_supports_utf8 */
+	/* Added a way to detect whether we'll use mkisofs or genisoimage */
 
-       	if (res && !g_strrstr (standard_error, "Unknown charset"))
+	prog_name = g_find_program_in_path ("mkisofs");
+        if (prog_name && g_file_test (prog_name, G_FILE_TEST_IS_EXECUTABLE)) {
+		gchar *standard_output = NULL;
+
+		res = g_spawn_command_line_sync ("mkisofs -version",
+						 &standard_output,
+						 NULL,
+						 NULL,
+						 NULL);
+		if (res) {
+			/* Really make sure it is mkisofs and not a symlink */
+			if (standard_output && strstr (standard_output, "genisoimage"))
+				priv->use_genisoimage = TRUE;
+
+			if (standard_output)
+				g_free (standard_output);
+		}
+		else
+			priv->use_genisoimage = TRUE;
+	}
+	else
+		priv->use_genisoimage = TRUE;
+
+	/* Don't use BRASERO_JOB_LOG () here!! */
+	if (priv->use_genisoimage)
+		res = g_spawn_command_line_sync ("genisoimage -input-charset utf8",
+						 NULL,
+						 &standard_error,
+						 NULL,
+						 NULL);
+	else
+	  	res = g_spawn_command_line_sync ("mkisofs -input-charset utf8",
+						 NULL,
+						 &standard_error,
+						 NULL,
+						 NULL);
+
+	if (res && !g_strrstr (standard_error, "Unknown charset"))
 		priv->use_utf8 = TRUE;
 	else
 		priv->use_utf8 = FALSE;
@@ -654,32 +717,34 @@ brasero_growisofs_finalize (GObject *object)
 static BraseroBurnResult
 brasero_growisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 {
-	gchar *prog_name;
+	BraseroPluginConfOption *use_dao;
+	gboolean use_dao_gconf_key;
+	BraseroBurnResult result;
+	GConfClient *client;
 	GSList *output;
 	GSList *input;
 
 	brasero_plugin_define (plugin,
 			       "growisofs",
-			       _("growisofs burns DVDs"),
+			       _("Growisofs burns DVDs"),
 			       "Philippe Rouquier",
 			       7);
 
-	/* First see if this plugin can be used, i.e. if growisofs is in
-	 * the path */
-	prog_name = g_find_program_in_path ("growisofs");
-	if (!prog_name) {
-		*error = g_strdup (_("growisofs could not be found in the path"));
-		return BRASERO_BURN_ERR;
-	}
-	g_free (prog_name);
+	/* First see if this plugin can be used */
+	result = brasero_process_check_path ("growisofs", error);
+	if (result != BRASERO_BURN_OK)
+		return result;
 
-	/* growisofs can write images to any type of DVD as long as it's blank */
+	/* growisofs can write images to any type of DVD-R as long as it's blank */
 	input = brasero_caps_image_new (BRASERO_PLUGIN_IO_ACCEPT_PIPE|
 					BRASERO_PLUGIN_IO_ACCEPT_FILE,
 					BRASERO_IMAGE_FORMAT_BIN);
 
-	output = brasero_caps_disc_new (BRASERO_MEDIUM_DVD|
-					BRASERO_MEDIUM_DVD_DL|
+	output = brasero_caps_disc_new (BRASERO_MEDIUM_BD|
+					BRASERO_MEDIUM_SRM|
+					BRASERO_MEDIUM_POW|
+					BRASERO_MEDIUM_DVD|
+					BRASERO_MEDIUM_DUAL_L|
 					BRASERO_MEDIUM_PLUS|
 					BRASERO_MEDIUM_JUMP|
 					BRASERO_MEDIUM_SEQUENTIAL|
@@ -699,8 +764,10 @@ brasero_growisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 	g_slist_free (output);
 
 	/* and images to DVD RW +/-(restricted) whatever the status */
-	output = brasero_caps_disc_new (BRASERO_MEDIUM_DVD|
-					BRASERO_MEDIUM_DVD_DL|
+	output = brasero_caps_disc_new (BRASERO_MEDIUM_BD|
+					BRASERO_MEDIUM_DVD|
+					BRASERO_MEDIUM_RAM|
+					BRASERO_MEDIUM_DUAL_L|
 					BRASERO_MEDIUM_PLUS|
 					BRASERO_MEDIUM_RESTRICTED|
 					BRASERO_MEDIUM_REWRITABLE|
@@ -714,8 +781,19 @@ brasero_growisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 	g_slist_free (input);
 
 	/* for DATA type recording discs can be also appendable */
-	output = brasero_caps_disc_new (BRASERO_MEDIUM_DVD|
-					BRASERO_MEDIUM_DVD_DL|
+	input = brasero_caps_data_new (BRASERO_IMAGE_FS_ISO|
+				       BRASERO_IMAGE_FS_UDF|
+				       BRASERO_IMAGE_ISO_FS_LEVEL_3|
+				       BRASERO_IMAGE_ISO_FS_DEEP_DIRECTORY|
+				       BRASERO_IMAGE_FS_JOLIET|
+				       BRASERO_IMAGE_FS_VIDEO);
+
+	output = brasero_caps_disc_new (BRASERO_MEDIUM_BD|
+					BRASERO_MEDIUM_SRM|
+					BRASERO_MEDIUM_POW|
+					BRASERO_MEDIUM_DVD|
+					BRASERO_MEDIUM_DUAL_L|
+					BRASERO_MEDIUM_RAM|
 					BRASERO_MEDIUM_PLUS|
 					BRASERO_MEDIUM_RESTRICTED|
 					BRASERO_MEDIUM_SEQUENTIAL|
@@ -726,20 +804,15 @@ brasero_growisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 					BRASERO_MEDIUM_BLANK|
 					BRASERO_MEDIUM_APPENDABLE|
 					BRASERO_MEDIUM_HAS_DATA);
-	
-	input = brasero_caps_data_new (BRASERO_IMAGE_FS_ISO|
-				       BRASERO_IMAGE_FS_UDF|
-				       BRASERO_IMAGE_ISO_FS_LEVEL_3|
-				       BRASERO_IMAGE_FS_JOLIET|
-				       BRASERO_IMAGE_FS_VIDEO);
-
 	brasero_plugin_link_caps (plugin, output, input);
 	g_slist_free (output);
 
 	/* growisofs has the possibility to record to closed DVD+RW/-restricted
-	 * and to append some more data to them which makes it unique */
-	output = brasero_caps_disc_new (BRASERO_MEDIUM_DVD|
-					BRASERO_MEDIUM_DVD_DL|
+	 * and to append some more data to them which makes them unique */
+	output = brasero_caps_disc_new (BRASERO_MEDIUM_BD|
+					BRASERO_MEDIUM_DVD|
+					BRASERO_MEDIUM_DUAL_L|
+					BRASERO_MEDIUM_RAM|
 					BRASERO_MEDIUM_PLUS|
 					BRASERO_MEDIUM_RESTRICTED|
 					BRASERO_MEDIUM_REWRITABLE|
@@ -749,185 +822,93 @@ brasero_growisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 	g_slist_free (output);
 	g_slist_free (input);
 
-	/* For DVD-W and DVD-RW sequential
-	 * NOTE: DAO et MULTI are exclusive. */
-	brasero_plugin_set_flags (plugin,
-				  BRASERO_MEDIUM_DVD|
-				  BRASERO_MEDIUM_DVD_DL|
-				  BRASERO_MEDIUM_SEQUENTIAL|
-				  BRASERO_MEDIUM_JUMP|
-				  BRASERO_MEDIUM_WRITABLE|
-				  BRASERO_MEDIUM_REWRITABLE|
-				  BRASERO_MEDIUM_UNFORMATTED|
-				  BRASERO_MEDIUM_BLANK,
-				  BRASERO_BURN_FLAG_BURNPROOF|
-				  BRASERO_BURN_FLAG_OVERBURN|
-				  BRASERO_BURN_FLAG_MULTI|
-				  BRASERO_BURN_FLAG_DUMMY|
-				  BRASERO_BURN_FLAG_NOGRACE,
-				  BRASERO_BURN_FLAG_NONE);
+	/* For DVD-RW sequential */
+	BRASERO_PLUGIN_ADD_STANDARD_DVDRW_FLAGS (plugin, BRASERO_BURN_FLAG_NONE);
 
-	brasero_plugin_set_flags (plugin,
-				  BRASERO_MEDIUM_DVD|
-				  BRASERO_MEDIUM_DVD_DL|
-				  BRASERO_MEDIUM_SEQUENTIAL|
-				  BRASERO_MEDIUM_JUMP|
-				  BRASERO_MEDIUM_WRITABLE|
-				  BRASERO_MEDIUM_REWRITABLE|
-				  BRASERO_MEDIUM_UNFORMATTED|
-				  BRASERO_MEDIUM_BLANK,
-				  BRASERO_BURN_FLAG_DAO|
-				  BRASERO_BURN_FLAG_BURNPROOF|
-				  BRASERO_BURN_FLAG_OVERBURN|
-				  BRASERO_BURN_FLAG_DUMMY|
-				  BRASERO_BURN_FLAG_NOGRACE,
-				  BRASERO_BURN_FLAG_NONE);
+	/* see NOTE for DVD-RW restricted overwrite */
+	BRASERO_PLUGIN_ADD_STANDARD_DVDRW_RESTRICTED_FLAGS (plugin, BRASERO_BURN_FLAG_NONE);
 
-	brasero_plugin_set_flags (plugin,
-				  BRASERO_MEDIUM_DVD|
-				  BRASERO_MEDIUM_DVD_DL|
-				  BRASERO_MEDIUM_SEQUENTIAL|
-				  BRASERO_MEDIUM_JUMP|
-				  BRASERO_MEDIUM_WRITABLE|
-				  BRASERO_MEDIUM_REWRITABLE|
-				  BRASERO_MEDIUM_APPENDABLE|
-				  BRASERO_MEDIUM_HAS_DATA,
-				  BRASERO_BURN_FLAG_BURNPROOF|
-				  BRASERO_BURN_FLAG_OVERBURN|
-				  BRASERO_BURN_FLAG_MULTI|
-				  BRASERO_BURN_FLAG_DUMMY|
-				  BRASERO_BURN_FLAG_NOGRACE|
-				  BRASERO_BURN_FLAG_APPEND|
-				  BRASERO_BURN_FLAG_MERGE,
-				  BRASERO_BURN_FLAG_NONE);
+	/* DVD+R and DVD-R. DAO and growisofs don't always work well with these
+	 * types of media and with some drives. So don't allow it if the
+	 * workaround is set in GConf. */
+	client = gconf_client_get_default ();
+	use_dao_gconf_key = gconf_client_get_bool (client,
+						   GCONF_KEY_DAO_FLAG,
+						   NULL);
+	g_object_unref (client);
+	if (use_dao_gconf_key == TRUE) {
+		BRASERO_PLUGIN_ADD_STANDARD_DVDR_FLAGS (plugin, BRASERO_BURN_FLAG_NONE);
+		BRASERO_PLUGIN_ADD_STANDARD_DVDR_PLUS_FLAGS (plugin, BRASERO_BURN_FLAG_NONE);
+	}
+	else {
+		/* All above standard flags minus DAO flag support */
+		brasero_plugin_set_flags (plugin,
+					  BRASERO_MEDIUM_DVDR_PLUS|
+					  BRASERO_MEDIUM_DUAL_L|
+					  BRASERO_MEDIUM_BLANK,                         
+					  (BRASERO_BURN_FLAG_BURNPROOF|                 
+					  BRASERO_BURN_FLAG_OVERBURN|                   
+					  BRASERO_BURN_FLAG_MULTI|                      
+					  BRASERO_BURN_FLAG_NOGRACE) &                  
+					  (~BRASERO_BURN_FLAG_NONE),                         
+					  BRASERO_BURN_FLAG_NONE);                      
 
-	/* see NOTE for DVD-RW restricted overwrite below */
-	brasero_plugin_set_flags (plugin,
-				  BRASERO_MEDIUM_DVD|
-				  BRASERO_MEDIUM_RESTRICTED|
-				  BRASERO_MEDIUM_REWRITABLE|
-				  BRASERO_MEDIUM_UNFORMATTED|
-				  BRASERO_MEDIUM_BLANK,
-				  BRASERO_BURN_FLAG_DAO|
-				  BRASERO_BURN_FLAG_MULTI|
-				  BRASERO_BURN_FLAG_BURNPROOF|
-				  BRASERO_BURN_FLAG_OVERBURN|
-				  BRASERO_BURN_FLAG_DUMMY|
-				  BRASERO_BURN_FLAG_NOGRACE|
-				  BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE,
-				  BRASERO_BURN_FLAG_MULTI);
+		brasero_plugin_set_flags (plugin,
+					  BRASERO_MEDIUM_DVDR_PLUS|
+					  BRASERO_MEDIUM_DUAL_L|
+					  BRASERO_MEDIUM_APPENDABLE|
+					  BRASERO_MEDIUM_HAS_DATA,
+					  (BRASERO_BURN_FLAG_MERGE|
+					  BRASERO_BURN_FLAG_APPEND|
+					  BRASERO_BURN_FLAG_BURNPROOF|
+					  BRASERO_BURN_FLAG_OVERBURN|
+					  BRASERO_BURN_FLAG_MULTI|
+					  BRASERO_BURN_FLAG_NOGRACE) &
+					  (~BRASERO_BURN_FLAG_NONE),
+					  BRASERO_BURN_FLAG_APPEND);
 
-	brasero_plugin_set_flags (plugin,
-				  BRASERO_MEDIUM_DVD|
-				  BRASERO_MEDIUM_RESTRICTED|
-				  BRASERO_MEDIUM_REWRITABLE|
-				  BRASERO_MEDIUM_APPENDABLE|
-				  BRASERO_MEDIUM_CLOSED|
-				  BRASERO_MEDIUM_HAS_DATA,
-				  BRASERO_BURN_FLAG_BURNPROOF|
-				  BRASERO_BURN_FLAG_OVERBURN|
-				  BRASERO_BURN_FLAG_MULTI|
-				  BRASERO_BURN_FLAG_DUMMY|
-				  BRASERO_BURN_FLAG_NOGRACE|
-				  BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE,
-				  BRASERO_BURN_FLAG_MULTI);
+		brasero_plugin_set_flags (plugin,
+					  BRASERO_MEDIUM_DVDR|
+					  BRASERO_MEDIUM_DUAL_L|
+					  BRASERO_MEDIUM_JUMP|
+					  BRASERO_MEDIUM_BLANK,
+					  (BRASERO_BURN_FLAG_BURNPROOF|
+					  BRASERO_BURN_FLAG_OVERBURN|
+					  BRASERO_BURN_FLAG_MULTI|
+					  BRASERO_BURN_FLAG_DUMMY|
+					  BRASERO_BURN_FLAG_NOGRACE) &
+					  (~BRASERO_BURN_FLAG_NONE),
+					  BRASERO_BURN_FLAG_NONE);
 
-	brasero_plugin_set_flags (plugin,
-				  BRASERO_MEDIUM_DVD|
-				  BRASERO_MEDIUM_RESTRICTED|
-				  BRASERO_MEDIUM_REWRITABLE|
-				  BRASERO_MEDIUM_APPENDABLE|
-				  BRASERO_MEDIUM_CLOSED|
-				  BRASERO_MEDIUM_HAS_DATA,
-				  BRASERO_BURN_FLAG_BURNPROOF|
-				  BRASERO_BURN_FLAG_OVERBURN|
-				  BRASERO_BURN_FLAG_MULTI|
-				  BRASERO_BURN_FLAG_DUMMY|
-				  BRASERO_BURN_FLAG_NOGRACE|
-				  BRASERO_BURN_FLAG_MERGE,
-				  BRASERO_BURN_FLAG_MULTI);
-
-	/* DVD+ R/RW don't support dummy mode */
-	brasero_plugin_set_flags (plugin,
-				  BRASERO_MEDIUM_DVDR_PLUS|
-				  BRASERO_MEDIUM_DVD_DL|
-				  BRASERO_MEDIUM_BLANK,
-				  BRASERO_BURN_FLAG_DAO|
-				  BRASERO_BURN_FLAG_BURNPROOF|
-				  BRASERO_BURN_FLAG_OVERBURN|
-				  BRASERO_BURN_FLAG_NOGRACE,
-				  BRASERO_BURN_FLAG_NONE);
-
-	brasero_plugin_set_flags (plugin,
-				  BRASERO_MEDIUM_DVDR_PLUS|
-				  BRASERO_MEDIUM_DVD_DL|
-				  BRASERO_MEDIUM_BLANK,
-				  BRASERO_BURN_FLAG_BURNPROOF|
-				  BRASERO_BURN_FLAG_OVERBURN|
-				  BRASERO_BURN_FLAG_MULTI|
-				  BRASERO_BURN_FLAG_NOGRACE,
-				  BRASERO_BURN_FLAG_NONE);
-
-	brasero_plugin_set_flags (plugin,
-				  BRASERO_MEDIUM_DVDR_PLUS|
-				  BRASERO_MEDIUM_DVD_DL|
-				  BRASERO_MEDIUM_APPENDABLE|
-				  BRASERO_MEDIUM_HAS_DATA,
-				  BRASERO_BURN_FLAG_BURNPROOF|
-				  BRASERO_BURN_FLAG_OVERBURN|
-				  BRASERO_BURN_FLAG_MULTI|
-				  BRASERO_BURN_FLAG_NOGRACE|
-				  BRASERO_BURN_FLAG_APPEND|
-				  BRASERO_BURN_FLAG_MERGE,
-				  BRASERO_BURN_FLAG_NONE);
-
-	/* NOTE: growisofs doesn't support APPEND flag with DVD+RW. DVD+RW and 
-	 * other overwrite media have only one session and therefore you can't
-	 * add another session after (APPEND). Now growisofs is still able to 
-	 * merge more data nevertheless. */
+		brasero_plugin_set_flags (plugin,
+					  BRASERO_MEDIUM_DVDR|
+					  BRASERO_MEDIUM_DUAL_L|
+					  BRASERO_MEDIUM_JUMP|
+					  BRASERO_MEDIUM_APPENDABLE|
+					  BRASERO_MEDIUM_HAS_DATA,
+					  (BRASERO_BURN_FLAG_APPEND|
+					  BRASERO_BURN_FLAG_MERGE|
+					  BRASERO_BURN_FLAG_BURNPROOF|
+					  BRASERO_BURN_FLAG_OVERBURN|
+					  BRASERO_BURN_FLAG_MULTI|
+					  BRASERO_BURN_FLAG_DUMMY|
+					  BRASERO_BURN_FLAG_NOGRACE) &
+					  (~BRASERO_BURN_FLAG_NONE),
+					  BRASERO_BURN_FLAG_APPEND);
+	}
 
 	/* for DVD+RW */
-	brasero_plugin_set_flags (plugin,
-				  BRASERO_MEDIUM_DVDRW_PLUS|
-				  BRASERO_MEDIUM_DVD_DL|
-				  BRASERO_MEDIUM_UNFORMATTED|
-				  BRASERO_MEDIUM_BLANK,
-				  BRASERO_BURN_FLAG_MULTI|
-				  BRASERO_BURN_FLAG_DAO|
-				  BRASERO_BURN_FLAG_BURNPROOF|
-				  BRASERO_BURN_FLAG_OVERBURN|
-				  BRASERO_BURN_FLAG_NOGRACE,
-				  BRASERO_BURN_FLAG_MULTI);
+	BRASERO_PLUGIN_ADD_STANDARD_DVDRW_PLUS_FLAGS (plugin, BRASERO_BURN_FLAG_NONE);
 
-	brasero_plugin_set_flags (plugin,
-				  BRASERO_MEDIUM_DVDRW_PLUS|
-				  BRASERO_MEDIUM_DVD_DL|
-				  BRASERO_MEDIUM_APPENDABLE|
-				  BRASERO_MEDIUM_CLOSED|
-				  BRASERO_MEDIUM_HAS_DATA,
-				  BRASERO_BURN_FLAG_BURNPROOF|
-				  BRASERO_BURN_FLAG_OVERBURN|
-				  BRASERO_BURN_FLAG_MULTI|
-				  BRASERO_BURN_FLAG_NOGRACE|
-				  BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE,
-				  BRASERO_BURN_FLAG_MULTI);
+	/* for BD-R */
+	BRASERO_PLUGIN_ADD_STANDARD_BD_R_FLAGS (plugin, BRASERO_BURN_FLAG_NONE);
 
-	brasero_plugin_set_flags (plugin,
-				  BRASERO_MEDIUM_DVDRW_PLUS|
-				  BRASERO_MEDIUM_DVD_DL|
-				  BRASERO_MEDIUM_APPENDABLE|
-				  BRASERO_MEDIUM_CLOSED|
-				  BRASERO_MEDIUM_HAS_DATA,
-				  BRASERO_BURN_FLAG_BURNPROOF|
-				  BRASERO_BURN_FLAG_OVERBURN|
-				  BRASERO_BURN_FLAG_MULTI|
-				  BRASERO_BURN_FLAG_NOGRACE|
-				  BRASERO_BURN_FLAG_MERGE,
-				  BRASERO_BURN_FLAG_MULTI);
+	/* for BD-RE */
+	BRASERO_PLUGIN_ADD_STANDARD_BD_RE_FLAGS (plugin, BRASERO_BURN_FLAG_NONE);
 
-	/* blank caps for +/restricted RW*/
+	/* blank caps for +/restricted RW */
 	output = brasero_caps_disc_new (BRASERO_MEDIUM_DVD|
-					BRASERO_MEDIUM_DVD_DL|
+					BRASERO_MEDIUM_DUAL_L|
 					BRASERO_MEDIUM_PLUS|
 					BRASERO_MEDIUM_RESTRICTED|
 					BRASERO_MEDIUM_REWRITABLE|
@@ -955,7 +936,7 @@ brasero_growisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 	/* again DVD+RW don't support dummy */
 	brasero_plugin_set_blank_flags (plugin,
 					BRASERO_MEDIUM_DVDRW_PLUS|
-					BRASERO_MEDIUM_DVD_DL|
+					BRASERO_MEDIUM_DUAL_L|
 					BRASERO_MEDIUM_APPENDABLE|
 					BRASERO_MEDIUM_HAS_DATA|
 					BRASERO_MEDIUM_BLANK|
@@ -965,6 +946,12 @@ brasero_growisofs_export_caps (BraseroPlugin *plugin, gchar **error)
 					BRASERO_BURN_FLAG_FAST_BLANK,
 					BRASERO_BURN_FLAG_FAST_BLANK);
 
+	use_dao = brasero_plugin_conf_option_new (GCONF_KEY_DAO_FLAG,
+						  _("Allow DAO use"),
+						  BRASERO_PLUGIN_OPTION_BOOL);
+
+	brasero_plugin_add_conf_option (plugin, use_dao); 
+
 	brasero_plugin_register_group (plugin, _(GROWISOFS_DESCRIPTION));
 
 	return BRASERO_BURN_OK;
